

do "$do/imputethis.do"
use "$rawfolder/hrs2002/H02J_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)

****************************
* 1. PREV wave employer:
*******************************

*if withdrew - means they withdrew all the money in the account when they left


* 0 : no w/d 1: withdrawal only 2: withdrawal + other option
forvalues i=1/4{

gen withdrawn_`i'=0
foreach val in A B {
	replace withdrawn_`i'=1 if HJ095_`i'`val'==1
}

}





*find amount in account when R left the job - those with w/d==1 will w/d all of this amount (only asked to DC/both type)

replace HJ091_2=9999998 if HJ091_2>=999998 & HJ091_2<1999999999 
replace HJ091_3=9999998 if HJ091_3>=999998 & HJ091_3<1999999999 
replace HJ091_4=9999998 if HJ091_4>=99998 & HJ091_4<1999999999 
forvalues val=1/4{

* Code missings (input for imputation code)
gen mmiss=.
replace mmiss=0 if HJ091_`val'<9999998 // donor group 
replace mmiss=1 if HJ091_`val'>9999997 & HJ091_`val'<1999999999 // missing variable code

replace HJ092_`val'=0 if mmiss==1 & HJ092_`val'==.
replace HJ093_`val'=1500000 if mmiss==1 & HJ093_`val'==.

* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=HJ091_`val'
replace exactvalue=99999998 if mmiss==1
gen double lowervalue=HJ092_`val'
gen double uppervalue=HJ093_`val'

gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=6
imputethis
drop yr

gen aleft`val'=exactvalue

drop exactvalue lowervalue uppervalue 


}



forvalues val=1/4{
gen plan_dc_wd_`val'=0	
replace plan_dc_wd_`val'=aleft`val' if withdrawn_`val'==1
}



*last year worked
gen lastyear=HJ064 if HJ064<9998
gen lastmonth=HJ063 if lastyear!=. & HJ063<=12
replace lastmonth=6 if lastyear!=. & lastmonth==.

gen months_since=HIWYEAR*12+HIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<HIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==HIWYEAR-1

egen dc_wd_total1 = rowtotal(plan_dc_wd_?)
replace dc_wd_total1=dc_wd_total1*monthsinlcy/months_since
replace dc_wd_total1=0 if dc_wd_total1==.

drop months_since monthsinlcy lastyear lastmonth plan_dc_wd_*


****************************
*dormant pensions from previous interviews
*******************************

*date of last interview
*find date of last interview
gen lastmonth=.
gen lastyear=.

foreach j in `c(ALPHA)' {
  if "`j'"<="G" {
    replace lastmonth=`j'IWMONTH if `j'IWMONTH!=.
	replace lastyear=`j'IWYEAR if `j'IWYEAR!=.
  }
}



*amount withdrawn (past pension - type B)

	
gen mmiss=.
replace mmiss=0 if HJ453_1 <999998 // donor group 
replace mmiss=1 if HJ453_1 >999997 & HJ453_1 <1999999999 // missing variable code


* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=HJ453_1
gen double lowervalue=0
gen double uppervalue=800000

gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=6
imputethis
drop yr

gen plan_dc_wd_1=exactvalue 
gen yearwd_1=HJ452_1 if HJ452_1<9998
drop exactvalue lowervalue uppervalue 

gen plan_dc_wd_2=0
replace plan_dc_wd_2=HJ453_2 if HJ453_2!=.
gen yearwd_2=HJ452_2 if HJ452_2<9998



*year of withdrawal is known in this section. However, to be consistent with other years, we wiJL also use date of last interview here.

*months since last interview
forvalues i=1/2{
gen months_since=HIWYEAR*12+HIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  yearwd_`i'<HIWYEAR-2 & HIWYEAR!=.
replace months_since=. if  lastyear<HIWYEAR-2 
replace months_since=24 if lastyear<HIWYEAR-2 & yearwd_`i'!=. & yearwd_`i'>=HIWYEAR-2

gen lastmonth`i'=lastmonth
replace lastmonth`i'=6 if lastyear<HIWYEAR-2 & yearwd_`i'!=. & yearwd_`i'>=HIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth`i' if lastyear==HIWYEAR-1

replace plan_dc_wd_`i'=plan_dc_wd_`i'*monthsinlcy/months_since

drop months_since monthsinlcy lastmonth`i'

}


egen dc_wd_total2=rowtotal(plan_dc_wd_1 plan_dc_wd_2)


egen dc_wd_totalJ = rowtotal(dc_wd_total*)
keep hhidpn dc_wd_totalJ
save "$folder\wave15\dcwtdr1_6.dta",replace



********************************************************************************
*                               Last Job
********************************************************************************


*only asked to those currently not working (and first interview)
use "${rawfolder}\hrs2002\H02K_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH BIRTHYR)

keep if HK026==1
keep if HK027!=0
count

* 0 : no w/d 1: withdrawal only 
forvalues i=1/3{

gen withdrawn_`i'=0
foreach val in A B {
	replace withdrawn_`i'=1 if HK034_`i'`val'==1
}

}

tab HK002 if withdrawn_1==1
tab HK002 if withdrawn_2==1
*very small number of accounts - both not in past two years ignore



gen dc_wd_totalK=0

keep hhidpn dc_wd_totalK

save "$folder\wave15\dcwtdr2_6.dta",replace


********************************************************************************
*                               Job History
********************************************************************************

*Only asked if first interview!
use "${rawfolder}\hrs2002\H02L_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH BIRTHYR)

keep if (HL027==1 & HL028!=0) | HL075==1 

count

* 0 : no w/d 1: withdrawal only 
forvalues i=1/3{

gen withdrawn_`i'=0
foreach val in A B {
	replace withdrawn_`i'=1 if HL036_`i'`val'==1
}

}

*missing one is not in last two years ignore
tab HL032_1 if withdrawn_1==1,m
tab HL016 if withdrawn_1==1 & HL032_1==999998 ,m
tab HL016 if withdrawn_1==1,m


gen plan_dc_wd_1=0
replace plan_dc_wd_1=HL032_1 if HL032_1<999998

gen plan_dc_wd_2=0
replace plan_dc_wd_2=HL032_2 if HL032_2<9998



*year last worked for job #1
gen lastyear=HL016 if HL016<9998
replace lastyear=HIWYEAR-HL017 if inlist(HL016,9998,9999) & HL017<=97
replace lastyear=BIRTHYR+ HL018 if HL018<=97
gen lastmonth=6 if lastyear!=. 


gen months_since=HIWYEAR*12+HIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<HIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth`i' if lastyear==HIWYEAR-1

egen dc_wd_totalL1=rowtotal(plan_dc_wd_1 plan_dc_wd_2)
replace dc_wd_totalL1 = dc_wd_totalL1*monthsinlcy/months_since
replace dc_wd_totalL1=0 if dc_wd_totalL1==.


drop withdrawn_* plan_dc_wd_* lastyear lastmonth months_since monthsinlcy

forvalues i=1/2{

gen withdrawn_`i'=0
foreach val in A B {
	replace withdrawn_`i'=1 if HL087_`i'`val'==1
}

}


tab HL083_1 if withdrawn_1==1,m
*only withdrawn from first account
tab HL079_1 if withdrawn_1==1 & HL083_1 ==99998 ,m
*missing account is very old -ignore


gen plan_dc_wd_1=0
replace plan_dc_wd_1=HL083_1 if HL083_1<99998



*year last worked for job #2
gen lastyear=HL079_1 if HL079_1<9998
gen lastmonth=6 if lastyear!=. 

gen months_since=HIWYEAR*12+HIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<HIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth`i' if lastyear==HIWYEAR-1

gen dc_wd_totalL2 = plan_dc_wd_1*monthsinlcy/months_since
replace dc_wd_totalL2=0 if dc_wd_totalL2==.


egen dc_wd_totalL= rowtotal(dc_wd_totalL*)
keep hhidpn dc_wd_totalL

save "$folder\wave15\dcwtdr3_6.dta",replace

use "$folder\wave15\dcwtdr1_6.dta",clear
merge 1:1 hhidpn using "$folder\wave15\dcwtdr2_6.dta",nogen
merge 1:1 hhidpn using "$folder\wave15\dcwtdr3_6.dta",nogen
egen r6dcw_ = rowtotal(dc_wd_total?)
drop dc_wd*
keep hhidpn r6*
save "$folder\wave15\dcwtdr_6.dta",replace
