
do "$do/imputethis.do"
use "$rawfolder/hrs2006/H06J_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)

****************************
* 1. PREV wave employer:
*******************************


* 0 : no w/d 1: withdrawal only 2: withdrawal + other option
foreach val in A B{

gen withdrawn_`val'=0
forvalues i=1/4{
	replace withdrawn_`val'=1 if KJW006`val'`i'==1
}

forvalues i=1/4{
	replace withdrawn_`val'=2 if !inlist(KJW006`val'`i',1,.,8,9) & withdrawn_`val'==1
}



}

foreach val in C D{
gen withdrawn_`val'=0
forvalues i=1/2{
	replace withdrawn_`val'=1 if KJW006`val'`i'==1
}

forvalues i=1/2{
	replace withdrawn_`val'=2 if !inlist(KJW006`val'`i',1,.,8,9) & withdrawn_`val'==1
}
}



*find amount in account when R left the job - those with w/d==1 will w/d all of this amount (only asked to DC/both type)

replace KJW002A=. if KJW002A==-2 //doesn't have an account
foreach val in A B C{

* Code missings (input for imputation code)
gen mmiss=.
replace mmiss=0 if KJW002`val'<99999998 // donor group 
replace mmiss=1 if KJW002`val'>99999997 & KJW002`val'<1999999999 // missing variable code

replace KJW003`val'=0 if mmiss==1 & KJW003`val'==.
replace KJW004`val'=99999996 if mmiss==1 & KJW004`val'==.

* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=KJW002`val'
replace exactvalue=99999998 if mmiss==1
gen double lowervalue=KJW003`val'
gen double uppervalue=KJW004`val'

gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=8
imputethis
drop yr


gen aleft`val'=exactvalue

drop exactvalue lowervalue uppervalue 


}

gen aleftD=0
replace aleftD=KJW002D if KJW002D!=.


*amount withdrawn (lump-sum/ cash)

foreach val in A{
	
* Impute for the missing
* Code missings (input for imputation code)
gen mmiss=.
replace mmiss=0 if KJW056`val'<99999998 // donor group 
replace mmiss=1 if KJW056`val'>99999997 & KJW056`val'<1999999999 // missing variable code


* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=KJW056`val'
gen double lowervalue=0
gen double uppervalue=600000


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=8
imputethis
drop yr

gen plan_dc_wd_`val'=exactvalue 
drop exactvalue lowervalue uppervalue 

	
}

gen plan_dc_wd_B=0
replace plan_dc_wd_B=KJW056B if KJW056B!=.
gen plan_dc_wd_C=0
gen plan_dc_wd_D=0 


foreach val in A B C D{
replace plan_dc_wd_`val'=aleft`val' if withdrawn_`val'==1
replace plan_dc_wd_`val'=0 if KJW057`val'==5
}



*last year worked
gen lastyear=KJ064 if KJ064<9998
gen lastmonth=KJ063 if lastyear!=. & KJ063<=12
replace lastmonth=6 if lastyear!=. & lastmonth==.

gen months_since=KIWYEAR*12+KIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<KIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==KIWYEAR-1

egen dc_wd_total1 = rowtotal(plan_dc_wd_?)
replace dc_wd_total1=dc_wd_total1*monthsinlcy/months_since
replace dc_wd_total1=0 if dc_wd_total1==.

drop months_since monthsinlcy lastyear lastmonth


****************************
*dormant pensions from previous interviews
*******************************

*date of last interview
*find date of last interview
gen lastmonth=.
gen lastyear=.

foreach j in `c(ALPHA)' {
  if "`j'"<="J" & "`j'"!="I" {
    replace lastmonth=`j'IWMONTH if `j'IWMONTH!=.
	replace lastyear=`j'IWYEAR if `j'IWYEAR!=.
  }
}



*amount withdrawn (past pension - type B)
local j=1
foreach val in A B C{
	
	
gen mmiss=.
replace mmiss=0 if KJ453`val'<99999998 // donor group 
replace mmiss=1 if KJ453`val'>99999997 & KJ453`val'<1999999999 // missing variable code


* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=KJ453`val'
gen double lowervalue=0
gen double uppervalue=800000


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=8
imputethis
drop yr

gen plan_dc_wd_`j'=exactvalue 
replace plan_dc_wd_`j'=0 if KJ667`val'==5

gen yearwd_`val'=KJ452`val' if KJ452`val'<9998

drop exactvalue lowervalue uppervalue 
local j=`j'+1
	
}


*year of withdrawal is known in this section. However, to be consistent with other years, we wiKL also use date of last interview here.

*months since last interview
local j=1
foreach i in A B C{
gen months_since=KIWYEAR*12+KIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  yearwd_`i'<KIWYEAR-2 & KIWYEAR!=.
replace months_since=. if  lastyear<KIWYEAR-2 
replace months_since=24 if lastyear<KIWYEAR-2 & yearwd_`i'!=. & yearwd_`i'>=KIWYEAR-2

gen lastmonth`i'=lastmonth
replace lastmonth`i'=6 if lastyear<KIWYEAR-2 & yearwd_`i'!=. & yearwd_`i'>=KIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth`i' if lastyear==KIWYEAR-1

replace plan_dc_wd_`j'=plan_dc_wd_`j'*monthsinlcy/months_since

drop months_since monthsinlcy lastmonth`i'
local j=`j'+1
}


egen dc_wd_total2=rowtotal(plan_dc_wd_1 plan_dc_wd_2 plan_dc_wd_3)


egen dc_wd_totalJ = rowtotal(dc_wd_total*)
keep hhidpn dc_wd_totalJ
save "$folder\wave15\dcwtdr1_8.dta",replace



********************************************************************************
*                               Last Job
********************************************************************************


*only asked to those currently not working (and first interview)
use "${rawfolder}\hrs2006\H06K_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH BIRTHYR)

keep if KK031==1
keep if KK032!=0
count

* 0 : no w/d 1: withdrawal only 2: withdrawal + other option
foreach val in A{

gen withdrawn_`val'=0
forvalues i=1/2{
	replace withdrawn_`val'=1 if KKW006`val'`i'==1
}

forvalues i=1/2{
	replace withdrawn_`val'=2 if !inlist(KKW006`val'`i',1,.,8,9) & withdrawn_`val'==1
}

}

*find amount in account when R left the job - those with w/d==1 will w/d all of this amount (only asked to DC/both type)

replace KKW002A=KKW003A if KKW003A == KKW004A & KKW003A!=.
replace KKW003A=. if KKW003A == KKW004A 
replace KKW004A=. if KKW003A == .

* Code missings (input for imputation code)
gen mmiss=.
replace mmiss=0 if KKW002A<99999998 // donor group 
replace mmiss=1 if KKW002A>99999997 & KKW002A<1999999999 // missing variable code

replace KKW003A=0 if mmiss==1 & KKW003A==.
replace KKW004A=99999996 if mmiss==1 & KKW004A==.

* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=KKW002A
replace exactvalue=99999998 if mmiss==1
gen double lowervalue=KKW003A
gen double uppervalue=KKW004A


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=8
imputethis
drop yr

gen aleftA=exactvalue

drop exactvalue lowervalue uppervalue 



*withdrawal 
* DC plan from last job (just two plans reported in 2004)
gen plan_dc_wd_A=0
replace plan_dc_wd_A=aleftA if withdrawn_A==1
replace plan_dc_wd_A=0 if KKW057A==5


*last year worked
gen lastyear=KK004 if KK004<9998
replace lastyear=KIWYEAR-KK005 if inlist(KK004,9998,9999) & KK005<=97
gen lastmonth=KK006 if lastyear!=. & KK006<=12
replace lastmonth=6 if lastyear!=. & lastmonth==.

gen months_since=KIWYEAR*12+KIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<KIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth`i' if lastyear==KIWYEAR-1


gen dc_wd_totalK=plan_dc_wd_A
replace dc_wd_totalK = dc_wd_totalK*monthsinlcy/months_since
replace dc_wd_totalK=0 if dc_wd_totalK==.


keep hhidpn dc_wd_totalK

save "$folder\wave15\dcwtdr2_8.dta",replace


********************************************************************************
*                               Job History
********************************************************************************

*Only asked if first interview!
use "${rawfolder}\hrs2006\H06L_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH BIRTHYR)

keep if (KL027==1 & KL028!=0) | KL031==1 
count

* 0 : no w/d 1: withdrawal only 2: withdrawal + other option
foreach val in A B E F {

gen withdrawn_`val'=0
forvalues i=1/2{
	replace withdrawn_`val'=1 if KLW006`val'`i'==1
}

forvalues i=1/2{
	replace withdrawn_`val'=2 if !inlist(KLW006`val'`i',1,.,8,9) & withdrawn_`val'==1
}

}

*only from A and B - total withdrawal

*find amount in account when R left the job - those with w/d==1 will w/d all of this amount (only asked to DC/both type)
foreach val in A B{

* Code missings (input for imputation code)
gen mmiss=.
replace mmiss=0 if KLW002`val'<99999998 // donor group 
replace mmiss=1 if KLW002`val'>99999997 & KLW002`val'<1999999999 // missing variable code

replace KLW003`val'=0 if mmiss==1 & KLW003`val'==.
replace KLW004`val'=99999996 if mmiss==1 & KLW004`val'==.

* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue=KLW002`val'
replace exactvalue=99999998 if mmiss==1
gen double lowervalue=KLW003`val'
gen double uppervalue=KLW004`val'


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=8
imputethis
drop yr

gen aleft`val'=exactvalue

drop exactvalue lowervalue uppervalue 


}


*withdrawal 
* no such withdrawal


foreach val in A B{
gen plan_dc_wd_`val'=0
replace plan_dc_wd_`val'=aleft`val' if withdrawn_`val'==1
replace plan_dc_wd_`val'=0 if KLW057`val'==5
}


*year last worked for job #1
gen lastyear=KL016 if KL016<9998
replace lastyear=KIWYEAR-KL017 if inlist(KL016,9998,9999) & KL017<=97
replace lastyear=BIRTHYR+ KL018 if KL018<=97
gen lastmonth=6 if lastyear!=. 

gen months_since=KIWYEAR*12+KIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<KIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth`i' if lastyear==KIWYEAR-1

egen dc_wd_totalL1=rowtotal(plan_dc_wd_A plan_dc_wd_B)
replace dc_wd_totalL1 = dc_wd_totalL1*monthsinlcy/months_since
replace dc_wd_totalL1=0 if dc_wd_totalL1==.


gen dc_wd_totalL= dc_wd_totalL1
keep hhidpn dc_wd_totalL

save "$folder\wave15\dcwtdr3_8.dta",replace

use "$folder\wave15\dcwtdr1_8.dta",clear
merge 1:1 hhidpn using "$folder\wave15\dcwtdr2_8.dta",nogen
merge 1:1 hhidpn using "$folder\wave15\dcwtdr3_8.dta",nogen
egen r8dcw_ = rowtotal(dc_wd_total?)
drop dc_wd*
keep hhidpn r8*
save "$folder\wave15\dcwtdr_8.dta",replace
