


do "$do/imputethis.do"

use "${rawfolder}\hrs2012\H12J_P.dta",clear

* # of pension records (raw data), # of individuals who are currently working for pay or have previous pension records in section PR_P (preloaded pension plans)
gen hhidpn = HHID+PN
destring hhidpn,replace
merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)

********************************************************************************
*	Drops plans that are inactive or not verified
********************************************************************************
* preloaded previous mentioned plans: NJ2Z139 could be as many as 7 plans
gen plan_prevwv = NJ2Z139
* Verified whether never have such preloaded pension plan. will be used to fix previous pension data in v2
gen verified = (NJ2W402==1)
* new plans (new people or new job or new plan)
gen plan_thiswv = 1 if NJ2W401==1
* plan active or dead
* dead plan assignment rules: page 7 of J2-QN. If active/dead missing, could be 1) W402 Verify failed 2) W404 lost all or DK/RF
gen plan_active = 0 if NJ2W451==1
replace plan_active = 1 if NJ2W451==5

keep if (NJ2W436==1 | NJ2W437==1)

********************************************************************************
*	Focus on DC plans
********************************************************************************
* if type is DK/RF/Missing, and no further info later, not DC
* if type is DK/RF/Missing, assign DC if all the following are satisfied: 
* 1) detailed type is DC
gen plan_dc = inlist(NJ2338,2,3)
replace plan_dc = 1 if inlist(NJ2338,8,9,.) &  !inlist(NJ2W407,.,2,97,98,99,96,16)
replace plan_dc = 1 if inlist(NJ2W425,1,2)  & !inlist(NJ2W428,1,2) & !inlist(NJ2W426,1,2)
keep if plan_dc==1


********************************************************************************
*	DC plan withdrawal
********************************************************************************

*find date of last interview
gen lastmonth=.
gen lastyear=.

foreach j in `c(ALPHA)' {
  if "`j'"<="M" & "`j'"!="I" {
    replace lastmonth=`j'IWMONTH if `j'IWMONTH!=.
	replace lastyear=`j'IWYEAR if `j'IWYEAR!=.
  }
}

replace lastyear=. if NJ2JOBNDX==10
replace lastmonth=. if NJ2JOBNDX==10

gen oldjob_np= 1 if NJ2W452==5 & NJ2JOBNDX==10
replace lastyear=NJ2W411 if oldjob_np==1 & NJ2W411!=-8 
replace lastmonth=6 if oldjob_np==1 & NJ2W411!=-8 // assume they left their jobs mid-year

*use start date for currentjob
gen currentjob_np=1 if NJ2W452==1 & NJ2JOBNDX==10
replace lastyear=NJ2W410 if currentjob_np==1
replace lastmonth=6 if currentjob_np==1


*lastyear is missing for old jobs with missing end years - assume 0 withdrawn in the LCY


gen months_since=NIWYEAR*12+NIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=24 if currentjob_np==1 & months_since>=24
replace months_since=. if currentjob_np==1 & lastyear>NIWYEAR-1
replace months_since=. if oldjob_np==1 & lastyear<NIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==NIWYEAR-1


*withdrawal amount

gen mmiss=.
replace mmiss= 0 if NJ2W063<9999998 // donor group
replace mmiss= 1 if NJ2W063>9999997 & NJ2W063<1999999999 // missing variable code
replace mmiss= 1 if NJ2W063==-8 // missing variable code


* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue = NJ2W063
replace exactvalue = 999999999 if mmiss==1
gen double lowervalue = 0
gen double uppervalue =999999996


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=11
imputethis
drop yr

gen dc_wd_totalJ=exactvalue
gen dc_wd_totalJ_imp=0 if NJ2W063<9999998  & NJ2W063!=-8
replace dc_wd_totalJ_imp=1 if (NJ2W063>9999997 & NJ2W063<1999999999) | NJ2W063==-8
*if rolled into IRA, make it zero
replace dc_wd_totalJ=0 if NJ2W453M1==5 & NJ2W453M2==. & NJ2W453M3==. & NJ2W453M4==.

replace dc_wd_totalJ=exactvalue/months_since*monthsinlcy


drop exactvalue uppervalue lowervalue

keep hhidpn dc_wd_totalJ*
collapse (sum) dc_wd_totalJ (sum) dc_wd_totalJ_imp, by(hhidpn)


save "$folder\wave15\dcwtdr1_11.dta",replace

********************************************************************************
*                               Last Job
********************************************************************************


*only asked to those currently not working (and first interview)
use "${rawfolder}\hrs2012\H12K_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)

keep if NK031==1
count

* DC plan from last job (up tp three plans - no one has 3 in 2012)
local i = 1
foreach plan in A B{
gen plan_dc_`i' = inlist(NKW001`plan',2,3)
replace plan_dc_`i'=1 if inlist(NKW001`plan',8,9) & !inlist(NKW082`plan',3,97,98,99,.)

replace NKW056`plan'=. if plan_dc_`i'==0

*small size use mediam for missing
gen plan_dc_wd_`i'=0 if plan_dc_`i'==1
replace plan_dc_wd_`i'=NKW056`plan' if plan_dc_`i'==1 & !missing(NKW056`plan')
sum NKW056`plan' if plan_dc_`i'==1 & !missing(NKW056`plan') & NKW056`plan'<99999998
replace plan_dc_wd_`i'=r(p50) if  !missing(NKW056`plan') & NKW056`plan'>=99999998
replace plan_dc_wd_`i'=0 if plan_dc_`i'==1 & !missing(NKW056`plan') & NKW057`plan'==5
 

local ++i

}
*last year worked
gen lastyear=NK004 if NK004<9998
replace lastyear=NIWYEAR-NK005 if inlist(NK004,9998,9999) & NK005<=12
gen lastmonth=NK006 if lastyear!=.
replace lastmonth=6 if lastyear!=. & lastmonth==.

gen months_since=NIWYEAR*12+NIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<NIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==NIWYEAR-1


egen dc_wd_totalK = rowtotal(plan_dc_wd_?),m
replace dc_wd_totalK=dc_wd_totalK*monthsinlcy/months_since
keep hhidpn dc_wd_totalK*

save "$folder\wave15\dcwtdr2_11.dta",replace


********************************************************************************
*                               Job History
********************************************************************************

*Only asked if first interview!
use "${rawfolder}\hrs2012\H12L_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)

keep if (NL027==1 & NL028!=0) | NL031==1 
count

* up to 6 plans from employers in the last 5 years

replace NLW056A=99999998 if NLW056A>=99998 & !missing(NLW056A)
replace NLW056F=99999998 if NLW056F>=99998 & !missing(NLW056F)
local list="A B C D E F"

foreach i in `list' {
gen plan_dc_`i' = inlist(NLW001`i',2,3)
replace plan_dc_`i'=1 if inlist(NLW001`i',8,9) & !inlist(NLW082`i',3,97,98,99,.)

replace NLW056`i'=. if plan_dc_`i'==0

* for DC
*since sample size is so small, use the median 
gen plan_dc_wd_`i'=0 if plan_dc_`i'==1
replace plan_dc_wd_`i'=NLW056`i' if plan_dc_`i'==1 & !missing(NLW056`i') & NLW056`i'<99999998
sum NLW056`i' if plan_dc_`i'==1 & !missing(NLW056`i') & NLW056`i'<99999998
replace plan_dc_wd_`i'=r(p50) if  !missing(NLW056`i') & NLW056`i'>=99999998

}

*last year worked job #1
gen lastyear=NL016 if NL016<9998
replace lastyear=NIWYEAR-NL017 if inlist(NL016,9998,9999)
gen lastmonth=6 if lastyear!=.
gen months_since=NIWYEAR*12+NIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<NIWYEAR-2
gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==NIWYEAR-1

egen dc_wd_totalL1 = rowtotal(plan_dc_wd_A plan_dc_wd_B plan_dc_wd_C plan_dc_wd_D),m
replace dc_wd_totalL1=dc_wd_totalL1*monthsinlcy/months_since

drop  lastyear lastmonth months_since monthsinlcy

*last year worked job #2
gen lastyear=NL035A  if NL035A <9998
gen lastmonth=6 if lastyear!=.
gen months_since=NIWYEAR*12+NIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<NIWYEAR-2
gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==NIWYEAR-1

replace plan_dc_wd_E=plan_dc_wd_E*monthsinlcy/months_since

drop  lastyear lastmonth months_since monthsinlcy

*last year worked job #3
gen lastyear=NL035B  if NL035B <9998
gen lastmonth=6 if lastyear!=.
gen months_since=NIWYEAR*12+NIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<NIWYEAR-2
gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==NIWYEAR-1

replace plan_dc_wd_F=plan_dc_wd_F*monthsinlcy/months_since

drop  lastyear lastmonth months_since monthsinlcy



egen dc_wd_totalL = rowtotal(plan_dc_wd_E plan_dc_wd_F dc_wd_totalL1),m
keep hhidpn dc_wd_totalL*
save "$folder\wave15\dcwtdr3_11.dta",replace




********************************************************************************
*                               combine
********************************************************************************



use "$folder\wave15\dcwtdr1_11.dta",clear
merge 1:1 hhidpn using "$folder\wave15\dcwtdr2_11.dta",nogen
merge 1:1 hhidpn using "$folder\wave15\dcwtdr3_11.dta",nogen
egen r11dcw_ = rowtotal(dc_wd_total?),m
egen r11dcw_imp = rowtotal(dc_wd_total?_imp)
keep hhidpn r11*
save "$folder\wave15\dcwtdr_11.dta",replace


