
*Pensions

do "$do/imputethis.do"




use "${rawfolder}\hrs2014\H14J_P.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)



********************************************************************************
*	Drops plans that are inactive or not verified
********************************************************************************
* preloaded previous mentioned plans: OJ2Z139 could be as many as 7 plans
gen plan_prevwv = OJ2Z139
* Verified whether never have such preloaded pension plan. will be used to fix previous pension data in v2
gen verified = (OJ2W402==1)
* new plans (new people or new job or new plan)
gen plan_thiswv = 1 if OJ2W401==1
* plan active or dead
* dead plan assignment rules: page 7 of J2-QN. If active/dead missing, could be 1) W402 Verify failed 2) W404 lost all or DK/RF
gen plan_active = 0 if OJ2W451==1
replace plan_active = 1 if OJ2W451==5

keep if OJ2W436==1 | OJ2W437==1


********************************************************************************
*	Focus on DC plans
********************************************************************************
* J2338 isn't asked to all plans - not asked to preloaded, those who left money in account or withdrew some
* if type is DK/RF/Missing, and no further info later, not DC
* if type is DK/RF/Missing, assign DC if all the following are satisfied: 
* 1)look at specific plan types
* 1)if also missing, preloaded plan type is DC 

gen plan_dc = inlist(OJ2338,2,3)
replace plan_dc = 1 if inlist(OJ2338,8,9,.) & !inlist(OJ2W407,.,2,97,98,99,96,16)
replace plan_dc = 1 if inlist(OJ2338,8,9,.)  & inlist(OJ2W407,.,98,99) & inlist(OJ2Z140,2,3)
replace plan_dc = 1 if inlist(OJ2W425,1,2)  & !inlist(OJ2W428,1,2) & !inlist(OJ2W426,1,2)
keep if plan_dc==1 

********************************************************************************
*	DC plan withdrawal
********************************************************************************

*find date of last interview
gen lastmonth=.
gen lastyear=.

foreach j in `c(ALPHA)' {
  if "`j'"<="N" & "`j'"!="I" {
    replace lastmonth=`j'IWMONTH if `j'IWMONTH!=.
	replace lastyear=`j'IWYEAR if `j'IWYEAR!=.
  }
}

replace lastyear=. if OJ2JOBNDX==10
replace lastmonth=. if OJ2JOBNDX==10

gen oldjob_np= 1 if OJ2W452==5 & OJ2JOBNDX==10
replace lastyear=OJ2W411 if oldjob_np==1 & OJ2W411!=-8 & OJ2W411<2050
replace lastmonth=6 if oldjob_np==1 & OJ2W411!=-8 // assume they left their jobs mid-year

*use start date for currentjob
gen currentjob_np=1 if OJ2W452==1 & OJ2JOBNDX==10
replace lastyear=OJ2W410 if currentjob_np==1
replace lastmonth=6 if currentjob_np==1


*lastyear is missing for old jobs with missing end years - assume 0 withdrawn in the LCY


gen months_since=OIWYEAR*12+OIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=24 if currentjob_np==1 & months_since>=24
replace months_since=. if currentjob_np==1 & lastyear>OIWYEAR-1
replace months_since=. if oldjob_np==1 & (lastyear<OIWYEAR-2 | lastyear>=OIWYEAR)

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==OIWYEAR-1


*withdrawal amount

gen mmiss=.
replace mmiss= 0 if OJ2W063<9999998 // donor group
replace mmiss= 1 if OJ2W063>9999997 & OJ2W063<1999999999 // missing variable code
replace mmiss= 1 if OJ2W063==-8 // missing variable code


* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue = OJ2W063
replace exactvalue = 999999999 if mmiss==1
gen double lowervalue = 0
gen double uppervalue =999999996


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
gen yr=12
imputethis
drop yr

gen dc_wd_totalJ=exactvalue
gen dc_wd_totalJ_imp=0 if OJ2W063<9999998  & OJ2W063!=-8
replace dc_wd_totalJ_imp=1 if (OJ2W063>9999997 & OJ2W063<1999999999) | OJ2W063==-8
*if rolled into IRA, make it zero
replace dc_wd_totalJ=0 if OJ2W453M1==5 & OJ2W453M2==. & OJ2W453M3==. & OJ2W453M4==.

replace dc_wd_totalJ=exactvalue/months_since*monthsinlcy


drop exactvalue uppervalue lowervalue

keep hhidpn dc_wd_totalJ*
collapse (sum) dc_wd_totalJ (sum) dc_wd_totalJ_imp, by(hhidpn)

*RMD?


save "$folder\wave15\dcwtdr1_12.dta",replace


********************************************************************************
*                               Last Job
********************************************************************************

*only asked to those currently not working (and first interview)

use "${rawfolder}\hrs2014\H14K_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)


keep if OK031==1
drop if OK032==0
count

* DC plan from last job (up tp three plans) - no one has 3
local i = 1
foreach plan in A B{
* plan type (OKW001A OKW001B OKW001C) 1-DB; 2-DC; 3-BOTH
gen plan_dc_`i' = inlist(OKW001`plan',2,3)
replace plan_dc_`i'=1 if inlist(OKW001`plan',8,9) & !inlist(OKW082`plan',3,97,98,99,.)

*no imputation was needed in 2014
gen plan_dc_wd_`i'=0 if plan_dc_`i'==1
replace plan_dc_wd_`i'=OKW056`plan' if plan_dc_`i'==1 & !missing(OKW056`plan')
replace plan_dc_wd_`i'=0 if plan_dc_`i'==1 & !missing(OKW056`plan') & OKW057`plan'==5

local ++i
}

*last year worked
gen lastyear=OK004 if OK004<9998
replace lastyear=OIWYEAR-OK005 if inlist(OK004,9998,9999)
gen lastmonth=OK006 if lastyear!=.
replace lastmonth=6 if lastyear!=. & lastmonth==.

gen months_since=OIWYEAR*12+OIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<OIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==OIWYEAR-1

egen dc_wd_totalK = rowtotal(plan_dc_wd_?),m

replace dc_wd_totalK=dc_wd_totalK*monthsinlcy/months_since

keep hhidpn dc_wd_totalK*

save "$folder\wave15\dcwtdr2_12.dta", replace

********************************************************************************
*                               Job History
********************************************************************************

*Only asked if first interview!
use "${rawfolder}\hrs2014\H14L_R.dta",clear
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)

keep if (OL027==1 & OL028!=0) | OL031==1 
count

* up to 4 plans from past employers  (at most 2 reported in 2014 (no E or F)) - no missing amount reported
local list="A B E"

foreach i in `list' {
gen plan_dc_`i' = inlist(OLW001`i',2,3)
replace plan_dc_`i'=1 if inlist(OLW001`i',8,9) & !inlist(OLW082`i',3,97,98,99,.)

*imputaion needed here
gen plan_dc_wd_`i'=0 if plan_dc_`i'==1
replace plan_dc_wd_`i'=OLW056`i' if plan_dc_`i'==1 & !missing(OLW056`i')
sum OLW056`i' if plan_dc_`i'==1 & !missing(OLW056`i') & OLW056`i'<999998
replace plan_dc_wd_`i'=r(p50) if  !missing(OLW056`i') & OLW056`i'>=999998
replace plan_dc_wd_`i'=0 if plan_dc_`i'==1 & !missing(OLW056`i') & OLW057`i'==5

}

*last year worked job #1
gen lastyear=OL016 if OL016<9998
replace lastyear=OIWYEAR-OL017 if inlist(OL016,9998,9999)
gen lastmonth=6 if lastyear!=.
gen months_since=OIWYEAR*12+OIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<OIWYEAR-2
gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==OIWYEAR-1

egen dc_wd_totalL1 = rowtotal(plan_dc_wd_A plan_dc_wd_B),m
replace dc_wd_totalL1=dc_wd_totalL1*monthsinlcy/months_since

drop  lastyear lastmonth months_since monthsinlcy

*last year worked job #2
gen lastyear=OL035A  if OL035A <9998
gen lastmonth=6 if lastyear!=.
gen months_since=OIWYEAR*12+OIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=. if  lastyear<OIWYEAR-2
gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==OIWYEAR-1


replace plan_dc_wd_E=plan_dc_wd_E*monthsinlcy/months_since


egen dc_wd_totalL = rowtotal(dc_wd_totalL1 plan_dc_wd_E),m



keep hhidpn dc_wd_totalL*
save "$folder\wave15\dcwtdr3_12.dta", replace





********************************************************************************
*                               combine
********************************************************************************




use "$folder\wave15\dcwtdr1_12.dta",clear
merge 1:1 hhidpn using "$folder\wave15\dcwtdr2_12.dta",nogen
merge 1:1 hhidpn using "$folder\wave15\dcwtdr3_12.dta",nogen
egen r12dcw_ = rowtotal(dc_wd_total?),m
egen r12dcw_imp = rowtotal(dc_wd_total?_imp)
keep hhidpn r12*
save "$folder\wave15\dcwtdr_12.dta",replace




