*-----------------------------------*
*             DC withdrawals        *
*-----------------------------------*


do "$do/imputethis.do"


*2020 (wave 15)

use "${rawfolder}\hrs2020\H20J2_P.dta",clear
gen hhidpn = hhid+pn
destring hhidpn,replace
order hhidpn
rename hhid HHID
rename pn PN

merge m:1 HHID PN using "$rawfolder\trk2020tr_r.dta", keep(1 3) keepusing(*IWYEAR *IWMONTH)
********************************************************************************
*	Focus on DC plans
********************************************************************************
* Assign plan_type: RJ2338. 1-DB; 2-DC; 3-Both. Why some missing? How to deal other or DK/RF (some have preload type)?
gen plan_dc = inlist(RJ2338,2,3)
* if missing, try to use detailed pension type
replace plan_dc = 1 if inlist(RJ2338,8,9,.,-8) & !inlist(RJ2W407,.,2,97,98,99,95,96,16,-8)
* if missing, try to use preload pension plan type: DC type
replace plan_dc = 1 if inlist(RJ2338,8,9,.,-8)  & inlist(RJ2W407,.,98,99,-8) & inlist(RJ2Z140,2,3)
replace plan_dc = 1 if inlist(RJ2W425,1,2)  & !inlist(RJ2W428,1,2) & !inlist(RJ2W426,1,2)
keep if plan_dc==1


*keep plans with status: Withdrew all money or withdrew some  money
keep if RJ2W436==1 | RJ2W437==1

*preloaded plans - "withdrew any amount since last interview date" - prorate to LCY
*newly added plans - "since you left that employer" -assume they w/d right away, if they left more than two years ago, make it zero - if in last two years, prorate to LCY
*what if it's from a current job? - assume it was drawn last 2 years?


*find date of last interview
gen lastmonth=.
gen lastyear=.

foreach j in `c(ALPHA)' {
  if "`j'"<="Q" & "`j'"!="I" {
    replace lastmonth=`j'IWMONTH if `j'IWMONTH!=.
	replace lastyear=`j'IWYEAR if `j'IWYEAR!=.
  }
}

*pLan from newly reported job
replace lastyear=. if RJ2JOBNDX==10
replace lastmonth=. if RJ2JOBNDX==10

*old job - new plan - use the year they left job
gen oldjob_np= 1 if RJ2W452==5 & RJ2JOBNDX==10
replace lastyear=RJ2W411 if oldjob_np==1 & RJ2W411!=-8 
replace lastmonth=6 if oldjob_np==1 & RJ2W411!=-8 // assume they left their jobs mid-year

*use start date for currentjob
gen currentjob_np=1 if RJ2W452==1 & RJ2JOBNDX==10
replace lastyear=RJ2W410 if currentjob_np==1
replace lastmonth=6 if currentjob_np==1


*lastyear is missing for old jobs with missing end years - assume 0 withdrawn in the LCY


gen months_since=RIWYEAR*12+RIWMONTH-(lastyear*12+lastmonth) if lastyear!=.
replace months_since=24 if currentjob_np==1 & months_since>=24
replace months_since=. if currentjob_np==1 & lastyear>RIWYEAR-1
replace months_since=. if oldjob_np==1 & lastyear<RIWYEAR-2

gen monthsinlcy=12 if months_since!=.
replace monthsinlcy=12-lastmonth if lastyear==RIWYEAR-1


*withdrawal amount

gen mmiss=.
replace mmiss= 0 if RJ2W063<9999998 // donor group
replace mmiss= 1 if RJ2W063>9999997 & RJ2W063<1999999999 // missing variable code
replace mmiss= 1 if RJ2W063==-8 // missing variable code


* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue = RJ2W063
replace exactvalue = 999999999 if mmiss==1
gen double lowervalue = 0
gen double uppervalue =999999996


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.
* Impute
imputethis

gen r15dcw_=exactvalue
gen r15dcw_imp=0 if RJ2W063<9999998  & RJ2W063!=-8
replace r15dcw_imp=1 if (RJ2W063>9999997 & RJ2W063<1999999999) | RJ2W063==-8
*if rolled into IRA, make it zero
replace r15dcw_=0 if RJ2W453M1==5 & RJ2W453M2==. & RJ2W453M3==. & RJ2W453M4==.

replace r15dcw_=exactvalue/months_since*monthsinlcy


drop exactvalue uppervalue lowervalue

keep hhidpn r15dcw_*
collapse (sum) r15dcw_ (sum) r15dcw_imp, by(hhidpn)


save "$folder\wave15\dcwtdr_15.dta",replace