
*Pensions




do "$do/imputethis.do"

use "${rawHRS}\hrs2012\H12J_P.dta",clear

rename N* w11*

* # of pension records (raw data), # of individuals who are currently working for pay or have previous pension records in section PR_P (preloaded pension plans)
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn
count
codebook hhidpn


* plan indexing vars
des w11J2Z139 w11J2W401 w11J2W402 w11J2W451  
* plan type type vars
des w11J2338 w11J2W425  w11J2929 w11J2931M1 
* account balance vars
des w11J2W009 w11J2W010 w11J2W011 

********************************************************************************
*	Drops plans that are inactive or not verified
********************************************************************************
* preloaded previous mentioned plans: w11J2Z139 could be as many as 7 plans
gen plan_prevwv = w11J2Z139
* Verified whether never have such preloaded pension plan. will be used to fix previous pension data in v2
gen verified = (w11J2W402==1)
* new plans (new people or new job or new plan)
gen plan_thiswv = 1 if w11J2W401==1
* plan active or dead
* dead plan assignment rules: page 7 of J2-QN. If active/dead missing, could be 1) W402 Verify failed 2) W404 lost all or DK/RF
gen plan_active = 0 if w11J2W451==1
replace plan_active = 1 if w11J2W451==5

* keep this wave new plans and verified preloaded plans
*keep if plan_thiswv == 1 | (plan_prevwv~=. & verified==1)
* keep active plans
keep if plan_active==1


********************************************************************************
*	Focus on DC plans
********************************************************************************
* if type is DK/RF/Missing, and no further info later, not DC
* if type is DK/RF/Missing, assign DC if all the following are satisfied: 
* 1) detailed type is DC
gen plan_dc = inlist(w11J2338,2)
replace plan_dc= 1 if w11J2338==3 & !inlist(w11J2W407,2,16,97,98,99)
replace plan_dc = 1 if inlist(w11J2338,8,9,.) &  !inlist(w11J2W407,.,2,97,98,99,96,16)
replace plan_dc = 1 if inlist(w11J2W425,1,2)  & !inlist(w11J2W428,1,2) & !inlist(w11J2W426,1,2)
keep if plan_dc==1

********************************************************************************
*	DC plan balance
********************************************************************************
* Code missings (input for imputation code)
gen mmiss=.
replace mmiss= 0 if w11J2W009<99999998 // donor group
replace mmiss= 1 if w11J2W009>99999997 & w11J2W009<1999999999 // missing variable code


* if any coding is needed
replace w11J2W010= 0 if w11J2W010==. & mmiss==1      //fix annoying quirk in data
replace w11J2W011= 99999996 if w11J2W011==. & mmiss==1    // fix annoying quirk in data

* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue = w11J2W009
gen double lowervalue = w11J2W010
gen double uppervalue = w11J2W011


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.

* Impute *
gen yr=11
imputethis
drop yr


* Plan DC balance

gen plan_dc_bal=exactvalue
gen plan_dc_bal_imp=0 
replace plan_dc_bal_imp=1 if (w11J2W009>=99999998 & w11J2W009!=.) 



* Individual DC Wealth
by hhidpn,sort: egen dc_wth_totalJ = total(plan_dc_bal),m
by hhidpn:egen dc_wth_totalJ_imp = max(plan_dc_bal_imp)
collapse (first) dc_wth_totalJ*,by(hhidpn)
save "${folder}\DC_2012J.dta", replace

********************************************************************************
*                               Last Job
********************************************************************************


*only asked to those currently not working (and first interview)
use "${rawHRS}\hrs2012\H12K_R.dta",clear

rename N* w11*

gen hhidpn = HHID+PN
destring hhidpn,replace

keep if w11K031==1
count

* DC plan from last job (up tp three plans - no one has 3 in 2012)
local i = 1
foreach plan in A B{
gen plan_dc_`i' = inlist(w11KW001`plan',2)
replace plan_dc_`i' =1 if  w11KW001`plan'==3 & !inlist(w11KW082`plan',2,16,97,98)

*since sample size is so small, use the median 
gen plan_dc_bal_`i'=0 if plan_dc_`i'==1
replace plan_dc_bal_`i'=w11KW009`plan' if plan_dc_`i'==1 & !missing(w11KW009`plan') & w11KW009`plan'<999998
sum w11KW009`plan' if plan_dc_`i'==1 & !missing(w11KW009`plan') & w11KW009`plan'<999998
replace plan_dc_bal_`i'=r(p50) if  !missing(w11KW009`plan') & w11KW009`plan'>=999998
 

local ++i

}
egen dc_wth_totalK = rowtotal(plan_dc_bal_?),m
keep hhidpn dc_wth_totalK*

save "${folder}\DC_2012K.dta", replace


********************************************************************************
*                               Job History
********************************************************************************

*Only asked if first interview!
use "${rawHRS}\hrs2012\H12L_R.dta",clear

rename N* w11*

gen hhidpn = HHID+PN
destring hhidpn,replace

keep if w11L027==1
count

* up to 6 plans from employers in the last 5 years

replace w11LW009B=999998 if w11LW009B>=9998 & !missing(w11LW009B)
replace w11LW009E=999998 if w11LW009E>=99998 & !missing(w11LW009E)
local list="A B C D E F"

foreach i in `list' {
gen plan_dc_`i' = inlist(w11LW001`i',2)
replace plan_dc_`i' =1 if  w11LW001`i'==3 & !inlist(w11LW082`i',2,16,97,98)

* for DC
*since sample size is so small, use the median 
gen plan_dc_bal_`i'=0 if plan_dc_`i'==1
replace plan_dc_bal_`i'=w11LW009`i' if plan_dc_`i'==1 & !missing(w11LW009`i') & w11LW009`i'<999998
sum w11LW009`i' if plan_dc_`i'==1 & !missing(w11LW009`i') & w11LW009`i'<999998
replace plan_dc_bal_`i'=r(p50) if  !missing(w11LW009`i') & w11LW009`i'>=999998


}
egen dc_wth_totalL = rowtotal(plan_dc_bal_?),m
keep hhidpn dc_wth_totalL*
save "${folder}\DC_2012L.dta", replace








use "${folder}\DC_2012J.dta",clear
merge 1:1 hhidpn using "${folder}\DC_2012K.dta",nogen
merge 1:1 hhidpn using "${folder}\DC_2012L.dta",nogen
egen dc_wth_total11 = rowtotal(dc_wth_total?),m
egen dc_wth_total11_imp = rowtotal(dc_wth_total?_imp)
rename (dc_wth_total11 ) (r11dc_wth )
save "${folder}\DC_2012.dta",replace



