
*Pensions





do "$do/imputethis.do"

use "${rawHRS}\hrs2014\H14J_P.dta",clear

rename O* w12*

* # of pension records (raw data), # of individuals who are currently working for pay or have previous pension records in section PR_P (preloaded pension plans)
gen hhidpn = HHID+PN
destring hhidpn,replace
order hhidpn
count
codebook hhidpn


* plan indexing vars
des w12J2Z139 w12J2W401 w12J2W402 w12J2W451  
* plan type type vars
des w12J2338 w12J2W425  w12J2929 w12J2931M1 
* account balance vars
des w12J2W009 w12J2W010 w12J2W011 

********************************************************************************
*	Drops plans that are inactive or not verified
********************************************************************************
* preloaded previous mentioned plans: w12J2Z139 could be as many as 7 plans
gen plan_prevwv = w12J2Z139
* Verified whether never have such preloaded pension plan. will be used to fix previous pension data in v2
gen verified = (w12J2W402==1)
* new plans (new people or new job or new plan)
gen plan_thiswv = 1 if w12J2W401==1
* plan active or dead
* dead plan assignment rules: page 7 of J2-QN. If active/dead missing, could be 1) W402 Verify failed 2) W404 lost all or DK/RF
gen plan_active = 0 if w12J2W451==1
replace plan_active = 1 if w12J2W451==5

* keep this wave new plans and verified preloaded plans
*keep if plan_thiswv == 1 | (plan_prevwv~=. & verified==1)
* keep active plans
keep if plan_active==1


********************************************************************************
*	Focus on DC plans
********************************************************************************
* J2338 isn't asked to all plans - not asked to preloaded, those who left money in account or withdrew some
* if type is DK/RF/Missing, and no further info later, not DC
* if type is DK/RF/Missing, assign DC if all the following are satisfied: 
* 1)look at specific plan types
* 1)if also missing, preloaded plan type is DC 

gen plan_dc = inlist(w12J2338,2)
replace plan_dc = 1 if w12J2338==3 & !inlist(w12J2W407,2,16,97,98,99)
replace plan_dc = 1 if inlist(w12J2338,8,9,.) & !inlist(w12J2W407,.,2,97,98,99,96,16)
replace plan_dc = 1 if inlist(w12J2338,8,9,.)  & inlist(w12J2W407,.,98,99) & inlist(w12J2Z140,2,3)
replace plan_dc = 1 if inlist(w12J2W425,1,2)  & !inlist(w12J2W428,1,2) & !inlist(w12J2W426,1,2)
keep if plan_dc==1 

********************************************************************************
*	DC plan balance
********************************************************************************


* Code missings (input for imputation code)
gen mmiss=.
replace mmiss= 0 if w12J2W009<99999998 // donor group
replace mmiss= 1 if w12J2W009>99999997 & w12J2W009<1999999999 // missing variable code


* if any coding is needed
replace w12J2W010= 0 if w12J2W010==. & mmiss==1      //fix annoying quirk in data
replace w12J2W011= 99999996 if w12J2W011==. & mmiss==1    // fix annoying quirk in data

* Code lower, upper, and exact values (input for imputation code)
gen double exactvalue = w12J2W009
gen double lowervalue = w12J2W010
gen double uppervalue = w12J2W011


gen exactvalue_imp=exactvalue
replace exactvalue_imp=.  if mmiss==1
replace exactvalue_imp=0  if exactvalue==.

* Impute *
gen yr=12
imputethis
drop yr


* Plan DC balance

gen plan_dc_bal=exactvalue
gen plan_dc_bal_imp=0 
replace plan_dc_bal_imp=1 if (w12J2W009>=99999998 & w12J2W009!=.) 


* Individual DC Wealth
by hhidpn,sort: egen dc_wth_totalJ = total(plan_dc_bal),m
by hhidpn:egen dc_wth_totalJ_imp = max(plan_dc_bal_imp)
collapse (first) dc_wth_totalJ*,by(hhidpn)
save "${folder}\DC_2014J.dta", replace


********************************************************************************
*                               Last Job
********************************************************************************

*only asked to those currently not working (and first interview)

use "${rawHRS}\hrs2014\H14K_R.dta",clear
rename O* w12*

gen hhidpn = HHID+PN
destring hhidpn,replace

keep if w12K031==1
drop if w12K032==0
count

* DC plan from last job (up tp three plans) - no one has 3
local i = 1
foreach plan in A B{
* plan type (w12KW001A w12KW001B w12KW001C) 1-DB; 2-DC; 3-BOTH
gen plan_dc_`i' = inlist(w12KW001`plan',2)
replace plan_dc_`i' =1 if  w12KW001`plan'==3 & !inlist(w12KW082`plan',2,16,97,98)

*no imputation was needed in 2014
gen plan_dc_bal_`i'=0 if plan_dc_`i'==1
replace plan_dc_bal_`i'=w12KW009`plan' if plan_dc_`i'==1 & !missing(w12KW009`plan')


local ++i
}


egen dc_wth_totalK = rowtotal(plan_dc_bal_?),m
keep hhidpn dc_wth_totalK*

save "${folder}\DC_2014K.dta", replace

********************************************************************************
*                               Job History
********************************************************************************

*Only asked if first interview!
use "${rawHRS}\hrs2014\H14L_R.dta",clear

rename O* w12*

gen hhidpn = HHID+PN
destring hhidpn,replace

keep if w12L027==1
keep if w12L028!=0
count

* up to 4 plans from past employers  (at most 2 reported in 2014 (no E or F)) - no missing amount reported
local list="A B"

foreach i in `list' {
gen plan_dc_`i' = inlist(w12LW001`i',2)
replace plan_dc_`i' =1 if  w12LW001`i'==3 & !inlist(w12LW082`i',2,16,97,98)

*no imputation was needed in 2014
gen plan_dc_bal_`i'=0 if plan_dc_`i'==1
replace plan_dc_bal_`i'=w12LW009`i' if plan_dc_`i'==1 & !missing(w12LW009`i')

}

egen dc_wth_totalL = rowtotal(plan_dc_bal_?),m
keep hhidpn dc_wth_totalL*
save "${folder}\DC_2014L.dta", replace





********************************************************************************
*                               combine
********************************************************************************




use "${folder}\DC_2014J.dta",clear
merge 1:1 hhidpn using "${folder}\DC_2014K.dta",nogen
merge 1:1 hhidpn using "${folder}\DC_2014L.dta",nogen
egen dc_wth_total12 = rowtotal(dc_wth_total?),m
egen dc_wth_total12_imp = rowtotal(dc_wth_total?_imp)
rename (dc_wth_total12 ) (r12dc_wth )
save "${folder}\DC_2014.dta",replace




