*           MERGE ALL DB and DC wealth together




use "$rand\randhrs1992_2020v1.dta",clear

gen long hhidpn_org=hhidpn
drop hhidpn
gen hhidpn = string(hhidpn_org,"%09.0f")


*          Merge in GST 1992-2010

merge 1:1 hhidpn using "$GST/penwlth_w1", keep(1 3) nogen

forvalues i=2/10{
merge 1:1 hhidpn using "$GST/upenwlth_w`i'", keep(1 3) nogen	
}

rename prv_DBwlth1 Uprv_DBwlth1
rename prv_DCwlth1 Uprv_DCwlth1


forvalues i=1/10{
	egen r`i'db_wth=rowtotal(Uprv_DBwlth`i' cur_DBwlth`i')
	egen r`i'dc_wth=rowtotal(Uprv_DCwlth`i' cur_DCwlth`i')
	
}

*adjust DB wealth so that long-term nominal interest rate is used as discount factor rather than 5.8
*8% change in wealth for each percentage point change in discount rate (8% implicitly assumes that benefits start around age 65)

*waves 1-10
matrix define lr=(6.2, 6.3, 6.3, 6.2, 6.3, 6, 5.7, 5.7, 5.7, 5.7, 5.7)

forvalues i=1/10{
	local adjust=lr[1,`i']-5.8
	display(`adjust')
	replace r`i'db_wth=r`i'db_wth*(1+0.08*(-`adjust'))
	
}

drop hhidpn
rename hhidpn_org hhidpn

*Merge rest of the waves

forvalues i=2012(2)2020{
merge 1:1 hhidpn using "$folder/DBWealth_`i'", keep(1 3) nogen	
merge 1:1 hhidpn using "$folder/DC_`i'", keep(1 3) nogen	
}


for num 11/15: replace rXdc_wth=0 if rXdc_wth==.
for num 11/15: replace rXdb_wth=0 if rXdb_wth==.
for num 11/15: replace rXdb_wth_2=0 if rXdb_wth_2==.


*demographic variables to be used in imputation

gen college=(inlist(raeduc,4,5))
gen nonwhite=(rarace!=1)
forvalues i=1/15{
	gen age`i'=r`i'iwendy-rabyear
	gen sage`i'=r`i'iwendy-s`i'byear
	replace sage`i'=age`i' if sage`i'==. & !inlist(s`i'hhidpn,0,.)
}


keep hhidpn s*hhidpn r*iwendy r*db_wth r*db_wth_2 r*dc_wth college nonwhite age* sage* hacoh ragender h*itot r*wthh h*aira

*Merge spouses' values
*get spouses ID
forval i = 1/15{
	preserve
	keep hhidpn r`i'dc_wth  r`i'db_wth*
	rename hhidpn s`i'hhidpn
	rename r`i'dc_wth s`i'dc_wth
	rename r`i'db_wth s`i'db_wth
	if `i'>=11{
	rename r`i'db_wth_2 s`i'db_wth_2
	}
	tempfile s`i'
	save `s`i''
	restore
	merge m:1 s`i'hhidpn using `s`i''
	drop if _merge==2
	drop _merge
}

merge 1:1 hhidpn using "$folder/missingspouse.dta", keep(1 3) nogen
*one person is in RAND but not in tracker

*impute for missing spouses
mi set wide 
mi register imputed s6dc_wth s6db_wth
mi impute monotone (pmm, knn(1)) s6dc_wth s6db_wth = ragender i.hacoh age6 sage6  i.nonwhite i.college r6dc_wth h6itot, replace add(1) force

replace s6dc_wth=_1_s6dc_wth if (r6missing==1 & r6iwendy!=.)
replace s6db_wth=_1_s6db_wth if (r6missing==1 & r6iwendy!=.)

mi unregister  s6dc_wth s6db_wth
forvalues i=7/10{
mi register imputed s`i'dc_wth s`i'db_wth
mi impute monotone (pmm, knn(1)) s`i'dc_wth s`i'db_wth = ragender i.hacoh age`i' sage`i'  i.nonwhite i.college r`i'dc_wth h`i'itot, replace add(1) force


replace s`i'dc_wth=_1_s`i'dc_wth if (r`i'missing==1 & r`i'iwendy!=.)
replace s`i'db_wth=_1_s`i'db_wth if (r`i'missing==1 & r`i'iwendy!=.)


mi unregister  s`i'dc_wth s`i'db_wth
}
forvalues i=11/15{
mi register imputed s`i'dc_wth s`i'db_wth s`i'db_wth_2
mi impute monotone (pmm, knn(1)) s`i'dc_wth s`i'db_wth s`i'db_wth_2 = ragender i.hacoh age`i' sage`i'  i.nonwhite i.college r`i'dc_wth h`i'itot, replace add(1) force


replace s`i'dc_wth=_1_s`i'dc_wth if (r`i'missing==1 & r`i'iwendy!=.)
replace s`i'db_wth=_1_s`i'db_wth if (r`i'missing==1 & r`i'iwendy!=.)
replace s`i'db_wth_2=_1_s`i'db_wth_2 if (r`i'missing==1 & r`i'iwendy!=.)


mi unregister  s`i'dc_wth s`i'db_wth s`i'db_wth_2
}


mi unset




forval i = 1/15{
	egen h`i'dc_wth = rowtotal(r`i'dc_wth s`i'dc_wth),m
	egen h`i'db_wth = rowtotal(r`i'db_wth s`i'db_wth),m
	replace h`i'dc_wth=. if r`i'iwendy==.
	replace h`i'db_wth=. if r`i'iwendy==.
	replace r`i'dc_wth=. if r`i'iwendy==.
	replace r`i'db_wth=. if r`i'iwendy==.
	replace s`i'dc_wth=. if r`i'iwendy==.
	replace s`i'db_wth=. if r`i'iwendy==.
	if `i'>=11{
	egen h`i'db_wth_2 = rowtotal(r`i'db_wth_2 s`i'db_wth_2),m
	replace h`i'db_wth_2=. if r`i'iwendy==.
	replace r`i'db_wth_2=. if r`i'iwendy==.
	replace s`i'db_wth_2=. if r`i'iwendy==.
	}
	
	egen h`i'dc_ira = rowtotal(h`i'dc_wth h`i'aira)
}

keep hhidpn s*db_wth* s*dc_wth r*db_wth* r*dc_wth h*db_wth* h*dc_wth h*dc_ira

save "${folder}\merged_pension.dta", replace