********************************************************************************
*                 Replacement Rate Calculations                                *
********************************************************************************

clear all
set more off 
set maxvar 30000




* read annuity rate matrix
foreach type in m f{
import excel "${annuity}\annuity_rate_`type'.xlsx", clear
mkmat *, mat(annuityrate_`type')
}




use "randhrs1992_2020v1.dta",clear
*merge missing spouses
merge 1:1 hhidpn using "$working/pension/missingspouse.dta", keep(1 3) nogen

*merge pension wealth
merge 1:1 hhidpn using "$working/pension/imputed_dc_db.dta", keep(1 3) nogen
*merge social security wealth
merge 1:1 hhidpn using "$working/hh_ssw.dta", keep(1 3) nogen
*merge pre-retirement income (AIME and Top 5 after 45 for R)
merge 1:1 hhidpn using "$working/preretirement2.dta", keep(1 3) gen(pmerge)

rename preret* r_preret*
rename AIME* r_AIME*


*for each wave, merge spouse's preretirement earnings
*flag households with no matched earnings or spouse doesn't have a match earnings

gen double hhidpn_org=hhidpn
drop hhidpn
forvalues i=1/15{
	gen double s`i'hhidpn_org=s`i'hhidpn
	rename s`i'hhidpn hhidpn
	merge m:1 hhidpn using "$working/preretirement2.dta", keep(1 3) gen(pmerge`i')
	rename preret* s`i'_preret*
	rename AIME* s`i'_AIME*
	drop hhidpn
}

rename s*hhidpn_org s*hhidpn
rename hhidpn_org hhidpn

*do both spouses have earnings match in that wave (excludes non-respondent spouses)
/*
forvalues i=1/15{
	gen doesbothmatch`i'=0
	replace doesbothmatch`i'=1 if r`i'iwendy!=.  & (s`i'hhidpn==0 | (!missing(s`i'hhidpn) & pmerge`i'==3))
}
*/

gen FRA=0
replace FRA = (65 * 12) if rabyear <= 1937
replace FRA = (65 * 12) + 2 if rabyear == 1938
replace FRA = (65 * 12) + 4 if rabyear == 1939
replace FRA = (65 * 12) + 6 if rabyear == 1940
replace FRA = (65 * 12) + 8 if rabyear == 1941
replace FRA = (65 * 12) + 10 if rabyear == 1942
replace FRA = (66 * 12) if inrange(rabyear, 1943, 1954)
qui: replace FRA = (66 * 12) + 2 if rabyear ==1955
qui: replace FRA = (66 * 12) + 4 if rabyear ==1956
qui: replace FRA = (66 * 12) + 6 if rabyear ==1957
qui: replace FRA = (66 * 12) + 8 if rabyear ==1958
qui: replace FRA = (66 * 12) + 10 if rabyear ==1959
qui: replace FRA = (67 * 12) if rabyear >=1960
tab FRA, m

gen FR =round(FRA/12)




*age X wave
gen a62w=.
gen a65w=.
gen a70w=.
gen aFRw=.

forvalues i=1/15{
	replace a62w=`i' if r`i'agey_m==62
	replace a65w=`i' if r`i'agey_m==65
	replace a70w=`i' if r`i'agey_m==70
	replace aFRw=`i' if r`i'agey_m==FR
}

*if missing, one year younger
forvalues i=1/15{
	replace a62w=`i' if r`i'agey_m==62-1 & a62w==.
	replace a65w=`i' if r`i'agey_m==65-1 & a65w==.
	replace a70w=`i' if r`i'agey_m==70-1 & a70w==.
	replace aFRw=`i' if r`i'agey_m==FR-1 & aFRw==.
}

*if missing, one year older
forvalues i=1/15{
	replace a62w=`i' if r`i'agey_m==62+1 & a62w==.
	replace a65w=`i' if r`i'agey_m==65+1 & a65w==.
	replace a70w=`i' if r`i'agey_m==70+1 & a70w==.
	replace aFRw=`i' if r`i'agey_m==FR+1 & aFRw==.
}

*has spouse
forvalues i=1/15{
	gen hasspouse`i'=0
	replace hasspouse`i'=1 if s`i'hhidpn!=. & s`i'hhidpn!=0
}


*Reshape to long form
keep hhidpn h*hhid hhid h*atotf h*atoth h*atotb h*atotw h*aira   h*dc_wth  h*db_wth hep* r_preret* s*_preret*  a*w hasspouse* r*wthh h*pickhh ragender rabyear FR hacohort r_AIME* s*_AIME* r*missingsp


rename (h*hhid h*atotf h*atoth h*aira h*atotb h*atotw h*dc_wth   h*db_wth s*_preret_earnings_real_62 s*_preret_earnings_real_65 s*_preret_earnings_real_70 s*_preret_earnings_real_FRAyr r*wthh h*pickhh s*_AIME62 s*_AIME65 s*_AIMEFR s*_AIME70 r*missingsp) ///
(h_hhid* hatotf* hatoth* haira* hatotb* hatotw*  hdc_wth*  hdb_wth* s_preret62_* s_preret65_* s_preret70_* s_preretFR_* rwthh* hpickhh* s_AIME62_* s_AIME65_* s_AIMEFR_* s_AIME70_* rmissingsp*)

reshape long h_hhid hatotf hatoth hatotw hatotb haira  hdc_wth  hdb_wth hep62_ hep65_ hepFR_ hep70_ s_preret62_ s_preret65_ s_preret70_ s_preretFR_ h hasspouse hpickhh rwthh s_AIME62_ s_AIME65_ s_AIMEFR_ s_AIME70_ rmissingsp, i(hhidpn) j(wv) 


g year = (wv*2)+1990

*turn to 2020 dollars
matrix CPI=(26.10, 26.70, 26.90, 27.00, 26.90, 27.30, 28.30, 29.10, 29.30, 29.80, 30.10, 30.40, 30.80, 31.20, 31.70, 32.60, 33.60, 35.00, 36.90, 39.00, 40.70, 42.10, 44.70, 49.60, 54.10, 57.20, 60.90, 65.60, 73.10, 82.90, 91.40, 96.90, 99.80, 103.30, 106.90, 108.60, 112.50, 117.00, 122.60, 129.00, 134.30, 138.20, 142.10, 145.60, 149.80, 154.10, 157.60, 159.70, 163.20, 168.90, 173.50, 175.90, 179.80, 184.50, 191.00, 197.10, 202.77, 211.05, 209.63, 213.97, 221.58, 226.23, 229.32, 232.77, 231.81, 234.08, 239.05, 245.15, 249.22, 252.25, 265.51, 287.98, 294.90, 301.97, 309.22, 316.64, 324.24, 332.02, 339.99, 348.15, 356.51, 365.06, 373.82, 382.80, 391.98, 401.39, 411.02, 420.89, 430.99, 441.33, 451.93, 462.77, 473.88, 485.25, 496.90, 508.82, 521.04, 533.54, 546.35, 559.46, 572.88, 586.63, 600.71, 615.13, 629.89, 645.01, 660.49, 676.34, 692.57, 709.20, 726.22, 743.65, 761.49, 779.77, 798.48)

foreach x in "hatotf" "hatoth" "haira" "hatotw" "hatotb" "hdc_wth"  "hdb_wth" "hep65_" "hep62_" "hepFR_" "hep70_" {
	
	g real_`x' = `x' *  CPI[1, 70] / CPI[1, year-1950] 
}

*preretirement earnings are already in 2020 dollars


foreach val in 62 65 FR 70{

************************************************
* Total wealth
************************************************

egen tot_wealth`val' = rowtotal(real_hatotf  real_hatoth  real_haira  real_hdc_wth  real_hdb_wth  real_hep`val'),m
egen tot_wealth_nohous`val' = rowtotal(real_hatotf  real_haira  real_hdc_wth  real_hdb_wth  real_hep`val'),m

foreach x in real_hatotf  real_hatoth  real_haira  real_hdc_wth  real_hdb_wth  real_hep`val'{
    replace `x' = 0 if `x'==. & tot_wealth`val'~=.
}

************************************************
* Pre-retirement income
************************************************
egen mean_max_five`val'=rowtotal(r_preret_earnings_real_`val' s_preret`val'_),m
egen mean_aime`val'=rowtotal(r_AIME`val' s_AIME`val'_),m

************************************************
* Annuitized retirement income
************************************************
* annuity factor at age X
gen annuity_factor`val' = annuityrate_m[rabyear-1899,`val']/100 if ragender == 1
replace annuity_factor`val' = annuityrate_f[rabyear-1899,`val']/100 if ragender == 2

* annuitized retirement income
gen annuitized_wealth`val'_nohous = annuity_factor`val'*tot_wealth_nohous`val'
gen annuitized_wealth`val' = annuity_factor`val'*tot_wealth`val'

*annuitized SS retirement income
gen annuitized_SS`val' = annuity_factor`val'*real_hep`val'

************************************************
* Income replacement rate 
************************************************
*Using top 5 earnings as pre-retirement
gen replacement`val' = annuitized_wealth`val'/mean_max_five`val'
gen replacement_nohous`val' = annuitized_wealth`val'_nohous/mean_max_five`val'
gen replacement_ss`val' = annuitized_SS`val'/mean_max_five`val'

*Using AIME as pre-retirement
gen replacement`val'_2 = annuitized_wealth`val'/mean_aime`val'
gen replacement_nohous`val'_2 = annuitized_wealth`val'_nohous/mean_aime`val'
gen replacement_ss`val'_2 = annuitized_SS`val'/mean_aime`val'
}




*for each household id, pick one person to represent household - oldest, if not unique hh head pick, if no unique men.


foreach val in 62 65 FR 70{

gen insample`val'=0
replace insample`val'=1 if a`val'w==wv

bys hhid: egen min_in`val'=min(a`val'w)
replace insample`val'=0 if  a`val'w!=min_in`val'

*for others pick the rand pick for that wave
bys hhid insample`val': gen ind`val'=_N
replace insample`val'=0 if  hpickhh==0 & ind`val'>=2 

drop ind`val'
*subhouseholds pick the man
bys hhid insample`val': gen ind`val'=_N
replace insample`val'=0 if  ragender & ind`val'>=2 

replace replacement`val'=. if insample`val'!=1
replace replacement_nohous`val'=. if insample`val'!=1
replace replacement_ss`val'=. if insample`val'!=1

replace replacement`val'_2=. if insample`val'!=1
replace replacement_nohous`val'_2=. if insample`val'!=1
replace replacement_ss`val'_2=. if insample`val'!=1

}

*Option: exclude households with missing spouse
foreach val in 62 65 FR 70{
replace replacement`val'=. if rmissing==1
replace replacement_nohous`val'=. if rmissing==1
replace replacement_ss`val'=. if rmissing==1


replace replacement`val'_2=. if rmissing==1
replace replacement_nohous`val'_2=. if rmissing==1
replace replacement_ss`val'_2=. if rmissing==1

	
}	

keep hhidpn replacement* rwthh hacoh hhid rmissing mean_max_five* mean_aime* annuitized_*

