********************************************************************************
*EPV of benefits if claimed at 65
********************************************************************************

clear all
set more off 
set maxvar 30000




use "$working\merged.dta",clear


*benefits from own work - from age 62 to 119

forvalues a=62/119{
	gen B`a'=SSB_65*cola`a'/cola65
	replace B`a'=0 if `a'<65
}


*benefit of spouse when respondent is 62 -119
for num 62/119: gen BX_s1=0
for num 62/119: gen BX_s2=0
for num 62/119: gen BX_s3=0
for num 62/119: gen BX_s4=0

forvalues a=62/119{
	*benefit stream is zero before spouse claims at age 65
	replace B`a'_s1=0 if year_`a'<byear1+65
	replace B`a'_s2=0 if year_`a'<byear2+65
	replace B`a'_s3=0 if year_`a'<byear3+65
	replace B`a'_s4=0 if year_`a'<byear4+65
	
	*if spouse is between 62-119, R could have benefits of spouse for those years 
	replace B`a'_s1=_1_SSB65*cola`a'/_1_cola65 if  year_`a'>=byear1+65 &  year_`a'<=byear1+119
	replace B`a'_s2=_2_SSB65*cola`a'/_2_cola65 if  year_`a'>=byear2+65 &  year_`a'<=byear2+119
	replace B`a'_s3=_3_SSB65*cola`a'/_3_cola65 if  year_`a'>=byear3+65 &  year_`a'<=byear3+119
	replace B`a'_s4=_4_SSB65*cola`a'/_4_cola65 if  year_`a'>=byear4+65 &  year_`a'<=byear4+119
	
	*benefit stream is zero after spouse is 119 - noone survives beyond 119
	replace B`a'_s1=0 if year_`a'>=byear1+119
	replace B`a'_s2=0 if year_`a'>=byear2+119
	replace B`a'_s3=0 if year_`a'>=byear3+119
	replace B`a'_s4=0 if year_`a'>=byear4+119
}




for num 1/4: rename B*_sX BsX_*
*gen _mi_miss=0
*mi unset
reshape long B Bs1_ Bs2_ Bs3_ Bs4_, i(hhidpn) j(age)
*for the oldest use 1900 levels
gen actual_rabyear=rabyear
gen actual_ragender=ragender
gen actual_age=age
gen year=actual_rabyear+age

forvalues w=1/15{
	local y=`w'*2+1990
	gen age`w'=r`w'agey_m
	replace age`w'=`y'-actual_rabyear if missing(r`w'agey_m)
	
	gen s1_age`w'=`y'-byear1
	gen s2_age`w'=`y'-byear2
	gen s3_age`w'=`y'-byear3
	gen s4_age`w'=`y'-byear4

}

merge 1:1 hhidpn actual_age using "$working\cp_tomerge.dta",keep(1 3) nogen



*discount factor ( long run nominal interest rates for each corresponding year's trustees report)
matrix define r=(6.2, 6.3, 6.3, 6.2, 6.3, 6, 5.7, 5.7, 5.7, 5.7, 5.7, 5.6, 5.3, 5.3, 4.7) 

forvalues i=1/15{
	
gen disc_`i'=0
replace disc_`i'=(1+r[1,`i']/100)^(actual_age-65) if age`i'<=65
replace disc_`i'=(1+r[1,`i']/100)^(actual_age - age`i') if age`i'>65  & age`i'!=.
replace disc_`i'=0 if actual_age<age`i' & age`i'!=.
}

*epv of SSW62 for each wave
*own history
forvalues i=1/15{
gen r_epv`i'=B/disc_`i'*r_clx/r_clx_w`i'
}
*spousal history - spousal
forvalues i=1/15{
gen ss_epv`i'=.
replace ss_epv`i'=max(0,0.5*(Bs1_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(s1_clx/s_clx_w`i')  if w`i'_sn==1 & mar_m10_1==1
replace ss_epv`i'=max(0,0.5*(Bs2_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(s2_clx/s_clx_w`i')  if w`i'_sn==2 & mar_m10_2==1
replace ss_epv`i'=max(0,0.5*(Bs3_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(s3_clx/s_clx_w`i')  if w`i'_sn==3 & mar_m10_3==1
replace ss_epv`i'=max(0,0.5*(Bs3_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(s4_clx/s_clx_w`i')  if w`i'_sn==4 & mar_m10_4==1

replace ss_epv`i'=0 if w`i'_sn==1 & mar_m10_1==0
replace ss_epv`i'=0 if w`i'_sn==2 & mar_m10_2==0
replace ss_epv`i'=0 if w`i'_sn==3 & mar_m10_3==0
replace ss_epv`i'=0 if w`i'_sn==4 & mar_m10_4==0


}

*spousal history - survivor's benefit
forvalues i=1/15{
gen su_epv`i'=.
replace su_epv`i'=max(0,(Bs1_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(1-(s1_clx/s_clx_w`i'))  if w`i'_sn==1 & mar_m10_1==1
replace su_epv`i'=max(0,(Bs2_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(1-(s2_clx/s_clx_w`i'))  if w`i'_sn==2 & mar_m10_2==1
replace su_epv`i'=max(0,(Bs3_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(1-(s3_clx/s_clx_w`i'))  if w`i'_sn==3 & mar_m10_3==1
replace su_epv`i'=max(0,(Bs3_ - B))/disc_`i'*(r_clx/r_clx_w`i')*(1-(s4_clx/s_clx_w`i'))  if w`i'_sn==4 & mar_m10_4==1

replace su_epv`i'=0 if w`i'_sn==1 & mar_m10_1==0
replace su_epv`i'=0 if w`i'_sn==2 & mar_m10_2==0
replace su_epv`i'=0 if w`i'_sn==3 & mar_m10_3==0
replace su_epv`i'=0 if w`i'_sn==4 & mar_m10_4==0


}

*CPI 1951-2065
matrix CPI=(26.10, 26.70, 26.90, 27.00, 26.90, 27.30, 28.30, 29.10, 29.30, 29.80, 30.10, 30.40, 30.80, 31.20, 31.70, 32.60, 33.60, 35.00, 36.90, 39.00, 40.70, 42.10, 44.70, 49.60, 54.10, 57.20, 60.90, 65.60, 73.10, 82.90, 91.40, 96.90, 99.80, 103.30, 106.90, 108.60, 112.50, 117.00, 122.60, 129.00, 134.30, 138.20, 142.10, 145.60, 149.80, 154.10, 157.60, 159.70, 163.20, 168.90, 173.50, 175.90, 179.80, 184.50, 191.00, 197.10, 202.77, 211.05, 209.63, 213.97, 221.58, 226.23, 229.32, 232.77, 231.81, 234.08, 239.05, 245.15, 249.22, 252.25, 265.51, 287.98, 294.90, 301.97, 309.22, 316.64, 324.24, 332.02, 339.99, 348.15, 356.51, 365.06, 373.82, 382.80, 391.98, 401.39, 411.02, 420.89, 430.99, 441.33, 451.93, 462.77, 473.88, 485.25, 496.90, 508.82, 521.04, 533.54, 546.35, 559.46, 572.88, 586.63, 600.71, 615.13, 629.89, 645.01, 660.49, 676.34, 692.57, 709.20, 726.22, 743.65, 761.49, 779.77, 798.48)



*total
forvalues i=1/15{
	egen epv_`i'=rowtotal(r_epv`i' ss_epv`i' su_epv`i'),m
	local y=`i'*2+1990
	gen cpi`i'=CPI[1,`y'-1950]
}



*adjust to each wave dollars
forvalues i=1/15{
bys hhidpn: egen epv65_`i'=total(epv_`i')
bys hhidpn: egen r_epv65_`i'=total(r_epv`i')
replace epv65_`i'=epv65_`i'*cpi`i'/cpi_65 if age`i'<=65
replace r_epv65_`i'=r_epv65_`i'*cpi`i'/cpi_65 if age`i'<=65
}

keep hhidpn epv65_* r_epv65_* imp_flag
duplicates drop
save "$working\SSW65.dta",replace