*-------------------------------------------------------------------------------*
**************     Back Out PIA from self reported SS Benefit    ****************
*-------------------------------------------------------------------------------*

clear all
set more off 
set maxvar 30000


use "randhrs1992_2020v1.dta",clear

***Full Retirement Age***

gen FRA = 65 if rabyear <= 1937
replace FRA = 65.16667 if rabyear == 1938 
replace FRA = 65.33333 if rabyear == 1939 
replace FRA = 65.50000 if rabyear == 1940 
replace FRA = 65.66667 if rabyear == 1941 
replace FRA = 65.83333 if rabyear == 1942 
replace FRA = 66.00000 if rabyear >= 1943 & rabyear <= 1954
replace FRA = 66.16667 if rabyear == 1955
replace FRA = 66.33333 if rabyear == 1956
replace FRA = 66.50000  if rabyear == 1957
replace FRA = 66.66667 if rabyear == 1958
replace FRA = 66.83333 if rabyear == 1959
replace FRA = 67.00000 if rabyear >= 1960

*No information of PIA bend points for cohorts born before 1917 (before 1977 amendments - different formula - will add later)
drop if rabyear <1917

gen r62yr = rabyear+62

********************************************************************************
*RAND's "rassageb" variable records first time SS income is received - it can also be disability or dependent benefits.
*For them use the first time with positive SS retirement income.

*Note: For some respondents, it is missing even though they have positive reported SS retirement income.
*********************************************************************************

*Age at the first wave with positive SS ret income in RAND (refers to the last calendar year)
gen agefirst=.
gen wavefirst=.
forvalues w=15(-1)1{
 replace agefirst=r`w'agey_e-1 if !missing(r`w'isret) & r`w'isret>0 & r`w'agey_e-1>=61
 replace wavefirst=`w' if !missing(r`w'isret) & r`w'isret>0 & r`w'agey_e-1>=61	
}

count if agefirst!=. & missing(rassageb)
*tab hacoh if agefirst!=. & missing(rassageb)
*mostly ahead cohort (66%) -most ahead cohort entered after 70 years old
*there are those who look like they didn't claim yet (.s) according to rassageb, but have positive r*isret 


gen firstint_age=.
gen lastint_age=.
forvalues i=15(-1)1{
 replace firstint_age=r`i'agey_b if r`i'agey_b!=.	
 replace lastint_age=r`i'agey_e if r`i'agey_e!=. & lastint_age==.	
}

gen rassageb_o=rassageb

*if entered at 62 or younger, use the first reported year
replace rassageb=agefirst if firstint_age<=62 & missing(rassageb) & agefirst!=.
*if entered at 63-65, use reported year
replace rassageb=agefirst if inrange(firstint_age,63,65) & missing(rassageb) & agefirst!=.
*if older than 65, use younger of reported or fra
replace rassageb=min(FRA,agefirst) if firstint_age>=65 & missing(rassageb) & agefirst!=.

count if agefirst!=. & missing(rassageb)



**************************************************
************ Primary Insurance Amount ************
**************************************************

*** Adjust for early/delayed retirement credit ***
*Source: http://www.socialsecurity.gov/oact/ProgData/ar_drc.html

cap drop own_perc*
qui: gen own_perc = 0		


*Retire at 62
replace own_perc =0.8 if rabyear<1938 & rassageb < 63            
replace own_perc =((79+1/6)/100) if rabyear==1938 & rassageb < 63                
replace own_perc =((78+1/3)/100) if rabyear==1939 & rassageb < 63                
replace own_perc =((77+1/2)/100) if rabyear==1940 & rassageb < 63               
replace own_perc =((76+2/3)/100) if rabyear==1941 & rassageb < 63               
replace own_perc =((75+5/6)/100) if rabyear==1942  & rassageb < 63             
replace own_perc =((75)/100) 	   if rabyear>1942 & rassageb < 63
replace own_perc =((74+1/6)/100) if rabyear==1955 & rassageb < 63               
replace own_perc =((73+1/3)/100) if rabyear==1956 & rassageb < 63               
replace own_perc =((72+1/2)/100) if rabyear==1957 & rassageb < 63             
replace own_perc =((71+2/3)/100) if rabyear==1958 & rassageb < 63                
replace own_perc =((70+5/6)/100) if rabyear==1959 & rassageb < 63               
replace own_perc =(70/100) 	   if rabyear>1959 & rassageb < 63               

*Retire at 63
replace own_perc =((86+2/3)/100) if rabyear<1938 & rassageb >= 63 & rassageb < 64               
replace own_perc =((85+5/9)/100) if rabyear==1938 & rassageb >= 63 & rassageb < 64                
replace own_perc =((84+4/9)/100) if rabyear==1939 & rassageb >= 63 & rassageb < 64                 
replace own_perc =((83+1/3)/100) if rabyear==1940 & rassageb >= 63 & rassageb < 64               
replace own_perc =((82+2/9)/100) if rabyear==1941  & rassageb >= 63 & rassageb < 64                
replace own_perc =((81+1/9)/100) if rabyear==1942 & rassageb >= 63 & rassageb < 64                 
replace own_perc =((80)/100) 	   if rabyear>1942 & rabyear<1955 & rassageb >= 63 & rassageb < 64  
replace own_perc =((79+1/6)/100) if rabyear==1955 & rassageb >= 63 & rassageb < 64                 
replace own_perc =((78+1/3)/100) if rabyear==1956 & rassageb >= 63 & rassageb < 64                 
replace own_perc =((77+1/2)/100) if rabyear==1957 & rassageb >= 63 & rassageb < 64                 
replace own_perc =((76+2/3)/100) if rabyear==1958 & rassageb >= 63 & rassageb < 64                
replace own_perc =((75+5/6)/100) if rabyear==1959 & rassageb >= 63 & rassageb < 64               
replace own_perc =(75/100)	   if rabyear>1959  & rassageb >= 63 & rassageb < 64              

*Retire at 64                                                                                     
replace own_perc =((93+1/3)/100) if rabyear<1938  & rassageb >= 64 & rassageb < 65                 
replace own_perc =((92+2/9)/100) if rabyear==1938 & rassageb >= 64 & rassageb < 65               
replace own_perc =((91+1/9)/100) if rabyear==1939 & rassageb >= 64 & rassageb < 65               
replace own_perc =((90)/100)	   if rabyear==1940 & rassageb >= 64 & rassageb < 65              
replace own_perc =((88+8/9)/100) if rabyear==1941 & rassageb >= 64 & rassageb < 65              
replace own_perc =((87+7/9)/100) if rabyear==1942  & rassageb >= 64 & rassageb < 65              
replace own_perc =((86+2/3)/100) if rabyear>1942 & rabyear<1955 & rassageb >= 64 & rassageb < 65 
replace own_perc =((85+5/9)/100) if rabyear==1955 & rassageb >= 64 & rassageb < 65               
replace own_perc =((84+4/9)/100) if rabyear==1956 & rassageb >= 64 & rassageb < 65               
replace own_perc =((83+1/3)/100) if rabyear==1957 & rassageb >= 64 & rassageb < 65              
replace own_perc =((82+2/9)/100) if rabyear==1958 & rassageb >= 64 & rassageb < 65               
replace own_perc =((81+1/9)/100) if rabyear==1959 & rassageb >= 64 & rassageb < 65               
replace own_perc =(80/100) 	   if rabyear>1959  & rassageb >= 64 & rassageb < 65              

*Retire at 65               
replace own_perc =((100)/100)    if rabyear<1938  & rassageb >= 65 & rassageb < 66              
replace own_perc =((98+8/9)/100) if rabyear==1938 & rassageb >= 65 & rassageb < 66               
replace own_perc =((97+7/9)/100) if rabyear==1939 & rassageb >= 65 & rassageb < 66              
replace own_perc =((96+2/3)/100) if rabyear==1940 & rassageb >= 65 & rassageb < 66                
replace own_perc =((95+5/9)/100) if rabyear==1941 & rassageb >= 65 & rassageb < 66              
replace own_perc =((94+4/9)/100) if rabyear==1942 & rassageb >= 65 & rassageb < 66               
replace own_perc =((93+1/3)/100) if rabyear>1942 & rabyear<1955 & rassageb >= 65 & rassageb < 66 
replace own_perc =((92+2/9)/100) if rabyear==1955 & rassageb >= 65 & rassageb < 66               
replace own_perc =((91+1/9)/100) if rabyear==1956 & rassageb >= 65 & rassageb < 66              
replace own_perc =((90)/100) 	 if rabyear==1957 & rassageb >= 65 & rassageb < 66               
replace own_perc =((88+8/9)/100) if rabyear==1958 & rassageb >= 65 & rassageb < 66               
replace own_perc =((87+7/9)/100) if rabyear==1959 & rassageb >= 65 & rassageb < 66              
replace own_perc =((86+2/3)/100) if rabyear>1959  & rassageb >= 65 & rassageb < 66   
            
*Retire at 66                 
replace own_perc =((103)/100) if rabyear<1925 & rassageb >= 66 & rassageb < 67              
replace own_perc =((103+1/2)/100) if rabyear>1924 & rabyear<1927 & rassageb >= 66 & rassageb < 67   
replace own_perc =((104)/100) if rabyear>1926 & rabyear<1929 & rassageb >= 66 & rassageb < 67   
replace own_perc =((104+1/2)/100) if rabyear>1928 & rabyear<1931 & rassageb >= 66 & rassageb < 67 
replace own_perc =((105)/100) if rabyear>1930 & rabyear<1933 & rassageb >= 66 & rassageb < 67   
replace own_perc =((105+1/2)/100) if rabyear>1932 & rabyear<1935 & rassageb >= 66 & rassageb < 67   
replace own_perc =((106)/100) if rabyear>1934 & rabyear<1937 & rassageb >= 66 & rassageb < 67 
replace own_perc =((106+1/2)/100) if rabyear==1937 & rassageb >= 66 & rassageb < 67                
replace own_perc =((105+5/12)/100) if rabyear==1938 & rassageb >= 66 & rassageb < 67                 
replace own_perc =((104+2/3)/100) if rabyear==1939 & rassageb >= 66 & rassageb < 67                 
replace own_perc =((103+1/2)/100) if rabyear==1940 & rassageb >= 66 & rassageb < 67               
replace own_perc =((102+1/2)/100) if rabyear==1941 & rassageb >= 66 & rassageb < 67                
replace own_perc =((101+1/4)/100) if rabyear==1942 & rassageb >= 66 & rassageb < 67                
replace own_perc =((100)/100) if rabyear>1942 & rabyear<1955 & rassageb >= 66 & rassageb < 67 
replace own_perc =((98+8/9)/100) if rabyear==1955 & rassageb >= 66 & rassageb < 67                
replace own_perc =((97+7/9)/100) if rabyear==1956 & rassageb >= 66 & rassageb < 67                 
replace own_perc =((96+2/3)/100) if rabyear==1957 & rassageb >= 66 & rassageb < 67                  
replace own_perc =((95+5/9)/100) if rabyear==1958 & rassageb >= 66 & rassageb < 67                
replace own_perc =((94+4/9)/100) if rabyear==1959 & rassageb >= 66 & rassageb < 67                
replace own_perc =((93+1/3)/100) if rabyear>1959 & rassageb >= 66 & rassageb < 67                 

*Retire at 67                     
replace own_perc =((106)/100) if rabyear<1925 & rassageb >= 67 & rassageb < 68                
replace own_perc =((107)/100) if rabyear>1924 & rabyear<1927 & rassageb >= 67 & rassageb < 68   
replace own_perc =((108)/100) if rabyear>1926 & rabyear<1929 & rassageb >= 67 & rassageb < 68  
replace own_perc =((109)/100) if rabyear>1928 & rabyear<1931 & rassageb >= 67 & rassageb < 68   
replace own_perc =((110)/100) if rabyear>1930 & rabyear<1933 & rassageb >= 67 & rassageb < 68  
replace own_perc =((111)/100) if rabyear>1932 & rabyear<1935 & rassageb >= 67 & rassageb < 68  
replace own_perc =((112)/100) if rabyear>1934 & rabyear<1937 & rassageb >= 67 & rassageb < 68  
replace own_perc =((113)/100) if rabyear==1937  & rassageb >= 67 & rassageb < 68              
replace own_perc =((111+11/12)/100) if rabyear==1938 & rassageb >= 67 & rassageb < 68                
replace own_perc =((111+2/3)/100) if rabyear==1939 & rassageb >= 67 & rassageb < 68                
replace own_perc =((110+1/2)/100) if rabyear==1940 & rassageb >= 67 & rassageb < 68                
replace own_perc =((110)/100) if rabyear==1941 & rassageb >= 67 & rassageb < 68                 
replace own_perc =((108+3/4)/100) if rabyear==1942 & rassageb >= 67 & rassageb < 68                
replace own_perc =((108)/100) if rabyear>1942 & rabyear<1955 & rassageb >= 67 & rassageb < 68  
replace own_perc =((106+2/3)/100) if rabyear==1955 & rassageb >= 67 & rassageb < 68                 
replace own_perc =((105+1/3)/100) if rabyear==1956 & rassageb >= 67 & rassageb < 68                
replace own_perc =((104)/100) if rabyear==1957 & rassageb >= 67 & rassageb < 68                
replace own_perc =((102+2/3)/100) if rabyear==1958 & rassageb >= 67 & rassageb < 68                
replace own_perc =((101+1/3)/100) if rabyear==1959 & rassageb >= 67 & rassageb < 68               
replace own_perc =((100)/100) if rabyear>1959 & rassageb >= 67 & rassageb < 68                  

*Retire at 68                     
replace own_perc =(((106)/100)+0.03) if rabyear<1925 & rassageb >= 68 & rassageb < 69              
replace own_perc =(((107)/100)+0.035) if rabyear>1924 & rabyear<1927 & rassageb >= 68 & rassageb < 69      
replace own_perc =(((108)/100)+0.04) if rabyear>1926 & rabyear<1929 & rassageb >= 68 & rassageb < 69  
replace own_perc =(((109)/100)+0.045) if rabyear>1928 & rabyear<1931 & rassageb >= 68 & rassageb < 69    
replace own_perc =(((110)/100)+0.05) if rabyear>1930 & rabyear<1933 & rassageb >= 68 & rassageb < 69 
replace own_perc =(((111)/100)+0.055) if rabyear>1932 & rabyear<1935 & rassageb >= 68 & rassageb < 69     
replace own_perc =(((112)/100)+0.06) if rabyear>1934 & rabyear<1937 & rassageb >= 68 & rassageb < 69  
replace own_perc =(((113)/100)+0.065) if rabyear==1937 & rassageb >= 68 & rassageb < 69                  
replace own_perc =(((111+11/12)/100)+0.065) if rabyear==1938 & rassageb >= 68 & rassageb < 69                
replace own_perc =(((111+2/3)/100)+0.07) if rabyear==1939 & rassageb >= 68 & rassageb < 69               
replace own_perc =(((110+1/2)/100)+0.07) if rabyear==1940 & rassageb >= 68 & rassageb < 69                 
replace own_perc =(((110)/100)+0.075) if rabyear==1941 & rassageb >= 68 & rassageb < 69                   
replace own_perc =(((108+3/4)/100)+0.075) if rabyear==1942 & rassageb >= 68 & rassageb < 69               
replace own_perc =(((108)/100)+0.08) if rabyear>1942 & rabyear<1955 & rassageb >= 68 & rassageb < 69  
replace own_perc =(((106+2/3)/100)+0.08) if rabyear==1955 & rassageb >= 68 & rassageb < 69                
replace own_perc =(((105+1/3)/100)+0.08) if rabyear==1956 & rassageb >= 68 & rassageb < 69               
replace own_perc =(((104)/100)+0.08) if rabyear==1957 & rassageb >= 68 & rassageb < 69                
replace own_perc =(((102+2/3)/100)+0.08) if rabyear==1958 & rassageb >= 68 & rassageb < 69                
replace own_perc =(((101+1/3)/100)+0.08) if rabyear==1959 & rassageb >= 68 & rassageb < 69                
replace own_perc =(((100)/100)+0.08) if rabyear>1959 & rassageb >= 68 & rassageb < 69                  

*Retire at 69                        
replace own_perc  =(((106)/100)+2*0.03) if rabyear<1925 & rassageb >= 69 & rassageb < 70                
replace own_perc =(((107)/100)+2*0.035) if rabyear>1924 & rabyear<1927 & rassageb >= 69 & rassageb < 70 
replace own_perc =(((108)/100)+2*0.04) if rabyear>1926 & rabyear<1929 & rassageb >= 69 & rassageb < 70 
replace own_perc =(((109)/100)+2*0.045) if rabyear>1928 & rabyear<1931 & rassageb >= 69 & rassageb < 70  
replace own_perc =(((110)/100)+2*0.05) if rabyear>1930 & rabyear<1933 & rassageb >= 69 & rassageb < 70  
replace own_perc =(((111)/100)+2*0.055) if rabyear>1932 & rabyear<1935 & rassageb >= 69 & rassageb < 70  
replace own_perc =(((112)/100)+2*0.06)  if rabyear>1934 & rabyear<1937 & rassageb >= 69 & rassageb < 70 
replace own_perc =(((113)/100)+2*0.065) if rabyear==1937 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((111+11/12)/100)+2*0.065) if rabyear==1938 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((111+2/3)/100)+2*0.07) if rabyear==1939 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((110+1/2)/100)+2*0.07) if rabyear==1940 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((110)/100)+2*0.075) if rabyear==1941 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((108+3/4)/100)+2*0.075) if rabyear==1942 & rassageb >= 69 & rassageb < 70              
replace own_perc =(((108)/100)+2*0.08) if rabyear>1942 & rabyear<1955 & rassageb >= 69 & rassageb < 70  
replace own_perc =(((106+2/3)/100)+2*0.08) if rabyear==1955 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((105+1/3)/100)+2*0.08) if rabyear==1956 & rassageb >= 69 & rassageb < 70               
replace own_perc =(((104)/100)+2*0.08) if rabyear==1957 & rassageb >= 69 & rassageb < 70              
replace own_perc =(((102+2/3)/100)+2*0.08) if rabyear==1958 & rassageb >= 69 & rassageb < 70             
replace own_perc =(((101+1/3)/100)+2*0.08) if rabyear==1959 & rassageb >= 69 & rassageb < 70             
replace own_perc =(((100)/100)+2*0.08) if rabyear>1959 & rassageb >= 69 & rassageb < 70                

*Retire at 70                                 
replace own_perc =(((106)/100)+3*0.03) if rabyear<1925  & rassageb >= 70             
replace own_perc =(((107)/100)+3*0.035) if rabyear>1924 & rabyear<1927 & rassageb >= 70     
replace own_perc =(((108)/100)+3*0.04) if rabyear>1926 & rabyear<1929 & rassageb >= 70 
replace own_perc =(((109)/100)+3*0.045) if rabyear>1928 & rabyear<1931 & rassageb >= 70 
replace own_perc =(((110)/100)+3*0.05) if rabyear>1930 & rabyear<1933 & rassageb >= 70 
replace own_perc =(((111)/100)+3*0.055) if rabyear>1932 & rabyear<1935 & rassageb >= 70   
replace own_perc =(((112)/100)+3*0.06) if rabyear>1934 & rabyear<1937 & rassageb >= 70 
replace own_perc =(((113)/100)+3*0.065) if rabyear==1937 & rassageb >= 70                  
replace own_perc =(((111+11/12)/100)+3*0.065) if rabyear==1938 & rassageb >= 70               
replace own_perc =(((111+2/3)/100)+3*0.07) if rabyear==1939 & rassageb >= 70               
replace own_perc =(((110+1/2)/100)+3*0.07) if rabyear==1940 & rassageb >= 70                
replace own_perc =(((110)/100)+3*0.075) if rabyear==1941 & rassageb >= 70               
replace own_perc =(((108+3/4)/100)+3*0.075) if rabyear==1942 & rassageb >= 70              
replace own_perc =(((108)/100)+3*0.08) if rabyear>1942 & rabyear<1955 & rassageb >= 70 
replace own_perc =(((106+2/3)/100)+3*0.08) if rabyear==1955 & rassageb >= 70                
replace own_perc =(((105+1/3)/100)+3*0.08) if rabyear==1956 & rassageb >= 70               
replace own_perc =(((104)/100)+3*0.08) if rabyear==1957 & rassageb >= 70              
replace own_perc =(((102+2/3)/100)+3*0.08) if rabyear==1958 & rassageb >= 70               
replace own_perc =(((101+1/3)/100)+3*0.08) if rabyear==1959 & rassageb >= 70               
replace own_perc =(((100)/100)+3*0.08) if rabyear>1959  & rassageb >= 70   

***********************************************************
************ Add medicare premium back to benefits ********
***********************************************************
*just the standard amount (1991(2)2023)
*ignore the earnings test for now

matrix define mdcare=(381.6, 493.2, 510, 525.6, 546, 648, 799.2, 1062, 1156.8, 1326, 1198.8, 1258.8, 1461.6, 1608, 1735.2, 2041.2)

forvalues w=1/15{
	replace r`w'isret=r`w'isret+mdcare[1,`w'] if !missing(r`w'isret) & r`w'isret>0
	replace s`w'isret=s`w'isret+mdcare[1,`w'] if !missing(s`w'isret) & s`w'isret>0
}

**************************************************
************ Benefits at the claiming age ********
**************************************************
  

*r*isret reports the amount received in the LCY. If a respondent started receving sometime in LCY, this amount won't reflect the annual value so if available use second available year.

*maximum a person can receive monthly 4055 in 2023, adjusted by cola to find other years (1991(2)2023)
matrix define maxben=(23295.79108, 24618.52609,  25965.84879,  27279.95443,28325.45868,  30079.08783,  31140.69916,33292.73945, 35182.40205,  37222.98137,  38563.0087, 39806.85855,  40483.57514, 41417.12638,  43258.03482,  46405.79224,  48660)

gen claimyear=max(61,rassageb)+rabyear if !missing(rassageb)
replace claimyear=min(70,rassageb)+rabyear if !missing(rassageb) & rassageb>70
gen PIA =.
gen PIAyr=.
forvalues w = 15(-1)1{
	replace r`w'isret=min(r`w'isret,maxben[1,`w']) if !missing(r`w'isret)
	replace s`w'isret=min(s`w'isret,maxben[1,`w']) if !missing(s`w'isret)
	
	replace PIA = r`w'isret/12/own_perc if r`w'isret > 0 & r`w'isret <. & r`w'iwendy != .  & claimyear<=r`w'iwendy-1
	replace PIAyr = r`w'iwendy-1 if r`w'isret > 0 & r`w'isret <. & r`w'iwendy != .  & claimyear<=r`w'iwendy-1
	*if it's not from your own earning history, make it zero
	replace PIA = 0 if r`w'isret > 0 & r`w'isret <. & r`w'iwendy != .  & claimyear<=r`w'iwendy-1 & r`w'isret<0.55*s`w'isret & !missing(s`w'isret) & !missing(r`w'mcurln) & r`w'mcurln>=10
}

*if not the full year (for 264 people)
forvalues w = 15(-1)1{
	gen aux=(claimyear-r`w'iwendy+1)
	replace PIA = r`w'isret/(1-aux)/12/own_perc if PIA==. &  r`w'isret > 0 & r`w'isret <. & r`w'iwendy != .  & inrange(aux,0,0.99)
	replace PIAyr = r`w'iwendy-1 if PIAyr==. & r`w'isret > 0 & r`w'isret <. & r`w'iwendy != .  & inrange(aux,0,0.99)
	*if it's not from your own earning history, make it zero
	replace PIA = 0 if r`w'isret > 0 & r`w'isret <. & r`w'iwendy != .  &  inrange(aux,0,0.99) & r`w'isret<0.55*s`w'isret & !missing(s`w'isret) & !missing(r`w'mcurln) & r`w'mcurln>=10
	drop aux
}



gen claimage=max(61,rassageb) if !missing(rassageb)
replace claimage=70 if !missing(rassageb) & rassageb>70


/*
*if older than 70 at last interview and still zero, make PIA zero --ignore for now - some people have steady income until last wave
gen islastzero=.
forvalues i=1/15{
	replace islastzero=1 if r`i'isret==0 
	replace islastzero=0 if r`i'isret>0 & !missing(r`i'isret) 
}
count if islastzero==1 & lastint_age>70 & PIA>0 & PIA!=.
replace PIA=0 if islastzero==1 & 
*/

*using COLA adjustments bring from PIAyr  to the FRA year
gen FRAyr=rabyear+round(FRA)
gen yr62=rabyear+62
gen yr65=rabyear+65
gen yr70=rabyear+70

* Starts at 1975 -2065
matrix COLA = (8.0,6.4,5.9,6.5,9.9,14.3,11.2,7.4,3.5,3.5,3.1,1.3,4.2,4.0,4.7,5.4,3.7,3.0,2.6,2.8,2.6,2.9,2.1,1.3,2.5,3.5,2.6,1.4,2.1,2.7,4.1,3.3,2.3,5.8,0.0,0.0,3.6,1.7,1.5,1.7,0.0,0.3,2.0,2.8,1.6,1.3,5.9,8.7,3.3,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4) 

*turn cola into index
matrix def COLA_ind=J(1,101,.)
matrix COLA_ind[1,1]=100
forvalues i=2/101{
	local j=`i'-1
	matrix COLA_ind[1,`i']=COLA_ind[1,`j']*(1+COLA[1,`i']/100)
}


gen cola=COLA_ind[1,PIAyr-1974]
gen colaFRA=COLA_ind[1,FRAyr-1974]
gen cola65=COLA_ind[1, yr65-1974]
gen cola62=COLA_ind[1, yr62-1974]
gen cola70=COLA_ind[1, yr70-1974]


*benefits if claimed at FRA (keeping earnings history same)
gen SSBFR=PIA*colaFRA/cola*12


*benefits if claimed age 62 (keeping earnings history same)
*early claiming penalty
gen dif62=round((FRA*12-62*12))
gen penal=1-dif62*(0.01)*(5/9) if dif62<36
replace penal=1-(36*(0.01)*(5/9) + (dif62-36)*(0.01)*(5/12)) if dif62>=36
gen SSB62=PIA*penal*cola62/cola*12


*benefits if claimed age 65 (keeping earnings history same)
*early claiming penalty
gen dif65=round((FRA*12-65*12))
gen penal65=1-dif65*(0.01)*(5/9) if dif65<36
replace penal65=1-(36*(0.01)*(5/9) + (dif65-36)*(0.01)*(5/12)) if dif65>=36

gen SSB65=PIA*penal65*cola65/cola*12

*age 70

gen dif70=round((70*12-FRA*12))
gen penal70=1+dif70*(0.01)*(1/4) if inrange(rabyear,1917,1924) 
replace penal70=1+dif70*(0.01)*(7/24) if inrange(rabyear,1925,1926) 
replace penal70=1+dif70*(0.01)*(1/3) if inrange(rabyear,1927,1928) 
replace penal70=1+dif70*(0.01)*(3/8) if inrange(rabyear,1929,1930) 
replace penal70=1+dif70*(0.01)*(5/12) if inrange(rabyear,1931,1932) 
replace penal70=1+dif70*(0.01)*(11/24) if inrange(rabyear,1933,1934) 
replace penal70=1+dif70*(0.01)*(1/2) if inrange(rabyear,1935,1936) 
replace penal70=1+dif70*(0.01)*(13/24) if inrange(rabyear,1937,1938)
replace penal70=1+dif70*(0.01)*(7/12) if inrange(rabyear,1939,1940)
replace penal70=1+dif70*(0.01)*(5/8) if inrange(rabyear,1941,1942)
replace penal70=1+dif70*(0.01)*(2/3) if rabyear>=1943

gen SSB70=PIA*penal70*cola70/cola*12

keep if PIA!=.
*using the SSB wealth for age closest to claimage, others will be imputed
keep hhidpn SSB* claimage
rename SSB* SSB*_ret

save "$working\ssb_retro.dta", replace