********************************************************************************
* Standardize longest job industry
********************************************************************************

clear all
set more off 
set maxvar 30000


use "randhrs1992_2020v1.dta",clear
*longest job industry
keep hhidpn r*jlind* r*jcind*

/*
Consistent industry codes
1: Agriculture/Forest/Fishing/Hunting
2: Mining
3: Manufacturing
4: Transportation/Utilities/Warehousing
5: Wholesale Trade
6: Retail Trade
7: Finance/Insurance/reas estate
8: Personal services
9: Entertainment/Recreation/arts
10: Professional/Scientific/Tech/Related Services, education services
11: Public administration
*/

forvalues i=1/15{
	
	gen r`i'jlind_n=.
	replace r`i'jlind_n=1 if r`i'jlind==1
	replace r`i'jlind_n=2 if r`i'jlind==2
	replace r`i'jlind_n=3 if r`i'jlind==3 |  r`i'jlind==4
	replace r`i'jlind_n=4 if r`i'jlind==5
	replace r`i'jlind_n=5 if r`i'jlind==6
	replace r`i'jlind_n=6 if r`i'jlind==7
	replace r`i'jlind_n=7 if r`i'jlind==8
	replace r`i'jlind_n=8 if r`i'jlind==10
	replace r`i'jlind_n=9 if r`i'jlind==11
	replace r`i'jlind_n=10 if r`i'jlind==9 |  r`i'jlind==12
	replace r`i'jlind_n=11 if r`i'jlind==13
	replace r`i'jlind_n=.o if r`i'jlind==.p |  r`i'jlind==.b
	
}

forvalues i=7/15{
	
	gen r`i'jlindb_n=.
	replace r`i'jlindb_n=1 if r`i'jlindb==1
	replace r`i'jlindb_n=2 if r`i'jlindb==2 |  r`i'jlindb==4
	replace r`i'jlindb_n=3 if r`i'jlindb==5
	replace r`i'jlindb_n=4 if r`i'jlindb==3 |  r`i'jlindb==8
	replace r`i'jlindb_n=5 if r`i'jlindb==6
	replace r`i'jlindb_n=6 if r`i'jlindb==7
	replace r`i'jlindb_n=7 if r`i'jlindb==10  |  r`i'jlindb==11
	replace r`i'jlindb_n=8 if r`i'jlindb==17
	replace r`i'jlindb_n=9 if r`i'jlindb==16
	replace r`i'jlindb_n=10 if inrange(r`i'jlindb,12,15) |  r`i'jlindb==18 |  r`i'jlindb==9
	replace r`i'jlindb_n=11 if r`i'jlindb==19
	replace r`i'jlindb_n=.o if r`i'jlindb==.p |  r`i'jlindb==.b
	
}


forvalues i=10/15{
	
	gen r`i'jlindc_n=.
	replace r`i'jlindc_n=1 if r`i'jlindc==1
	replace r`i'jlindc_n=2 if r`i'jlindc==2 |  r`i'jlindc==4
	replace r`i'jlindc_n=3 if r`i'jlindc==5
	replace r`i'jlindc_n=4 if r`i'jlindc==3 |  r`i'jlindc==8
	replace r`i'jlindc_n=5 if r`i'jlindc==6
	replace r`i'jlindc_n=6 if r`i'jlindc==7
	replace r`i'jlindc_n=7 if r`i'jlindc==10  |  r`i'jlindc==11
	replace r`i'jlindc_n=8 if r`i'jlindc==17
	replace r`i'jlindc_n=9 if r`i'jlindc==16
	replace r`i'jlindc_n=10 if inrange(r`i'jlindc,12,15) |  r`i'jlindc==18 |  r`i'jlindc==9
	replace r`i'jlindc_n=11 if r`i'jlindc==19
	replace r`i'jlindc_n=.o if r`i'jlindc==.p |  r`i'jlindc==.b
	
}

drop r*jlind r*jlindb r*jlindc

forvalues i=1/15{
	gen r`i'jlind=.
	replace r`i'jlind=r`i'jlind_n if !missing(r`i'jlind_n)
	if `i'>=7{
		*replace r`i'jlind=r`i'jlindb_n if r`i'jlind_n==.o & !missing(r`i'jlindb_n)
		replace r`i'jlind=r`i'jlindb_n if missing(r`i'jlind_n) & !missing(r`i'jlindb_n)
	}
	if `i'>=10{
		*replace r`i'jlind=r`i'jlindc_n if r`i'jlind_n==.o & r`i'jlindb_n==.o & !missing(r`i'jlindc_n)
		replace r`i'jlind=r`i'jlindc_n if missing(r`i'jlind_n) & missing(r`i'jlindb_n) & !missing(r`i'jlindc_n)
	}
}

drop r*jlind_n r*jlindb_n r*jlindc_n

*find the latest longest job
gen rlongj=.
forvalues i=1/15{
	replace rlongj=r`i'jlind if !missing(r`i'jlind)
	
}

*current job

forvalues i=1/15{
	
	gen r`i'jcind_n=.
	replace r`i'jcind_n=1 if r`i'jcind==1
	replace r`i'jcind_n=2 if r`i'jcind==2
	replace r`i'jcind_n=3 if r`i'jcind==3 |  r`i'jcind==4
	replace r`i'jcind_n=4 if r`i'jcind==5
	replace r`i'jcind_n=5 if r`i'jcind==6
	replace r`i'jcind_n=6 if r`i'jcind==7
	replace r`i'jcind_n=7 if r`i'jcind==8
	replace r`i'jcind_n=8 if r`i'jcind==10
	replace r`i'jcind_n=9 if r`i'jcind==11
	replace r`i'jcind_n=10 if r`i'jcind==9 |  r`i'jcind==12
	replace r`i'jcind_n=11 if r`i'jcind==13
	replace r`i'jcind_n=.o if r`i'jcind==.p |  r`i'jcind==.b
	
}

forvalues i=7/15{
	
	gen r`i'jcindb_n=.
	replace r`i'jcindb_n=1 if r`i'jcindb==1
	replace r`i'jcindb_n=2 if r`i'jcindb==2 |  r`i'jcindb==4
	replace r`i'jcindb_n=3 if r`i'jcindb==5
	replace r`i'jcindb_n=4 if r`i'jcindb==3 |  r`i'jcindb==8
	replace r`i'jcindb_n=5 if r`i'jcindb==6
	replace r`i'jcindb_n=6 if r`i'jcindb==7
	replace r`i'jcindb_n=7 if r`i'jcindb==10  |  r`i'jcindb==11
	replace r`i'jcindb_n=8 if r`i'jcindb==17
	replace r`i'jcindb_n=9 if r`i'jcindb==16
	replace r`i'jcindb_n=10 if inrange(r`i'jcindb,12,15) |  r`i'jcindb==18 |  r`i'jcindb==9
	replace r`i'jcindb_n=11 if r`i'jcindb==19
	replace r`i'jcindb_n=.o if r`i'jcindb==.p |  r`i'jcindb==.b
	
}


forvalues i=10/15{
	
	gen r`i'jcindc_n=.
	replace r`i'jcindc_n=1 if r`i'jcindc==1
	replace r`i'jcindc_n=2 if r`i'jcindc==2 |  r`i'jcindc==4
	replace r`i'jcindc_n=3 if r`i'jcindc==5
	replace r`i'jcindc_n=4 if r`i'jcindc==3 |  r`i'jcindc==8
	replace r`i'jcindc_n=5 if r`i'jcindc==6
	replace r`i'jcindc_n=6 if r`i'jcindc==7
	replace r`i'jcindc_n=7 if r`i'jcindc==10  |  r`i'jcindc==11
	replace r`i'jcindc_n=8 if r`i'jcindc==17
	replace r`i'jcindc_n=9 if r`i'jcindc==16
	replace r`i'jcindc_n=10 if inrange(r`i'jcindc,12,15) |  r`i'jcindc==18 |  r`i'jcindc==9
	replace r`i'jcindc_n=11 if r`i'jcindc==19
	replace r`i'jcindc_n=.o if r`i'jcindc==.p |  r`i'jcindc==.b
	
}

drop r*jcind r*jcindb r*jcindc

forvalues i=1/15{
	gen r`i'jcind=.
	replace r`i'jcind=r`i'jcind_n if !missing(r`i'jcind_n)
	if `i'>=7{
		*replace r`i'jcind=r`i'jcindb_n if r`i'jcind_n==.o & !missing(r`i'jcindb_n)
		replace r`i'jlind=r`i'jcindb_n if missing(r`i'jcind_n) & !missing(r`i'jcindb_n)
	}
	if `i'>=10{
		*replace r`i'jcind=r`i'jcindc_n if r`i'jcind_n==.o & r`i'jcindb_n==.o & !missing(r`i'jcindc_n)
		replace r`i'jcind=r`i'jcindc_n if missing(r`i'jcind_n) & missing(r`i'jcindb_n) & !missing(r`i'jcindc_n)
	}
}

drop r*jcind_n r*jcindb_n r*jcindc_n

*find the latest longest job
gen rcurj=.
forvalues i=1/15{
	replace rcurj=r`i'jcind if !missing(r`i'jcind)
	
}

gen indust=rlongj
replace indust=rcurj if indust==.

keep hhidpn rlongj rcurj indust
save "$working\industry.dta",replace
