********************************************************************************
* Merge benefits calculated using earnings file with retrospective calculations
* Impute the missing
********************************************************************************

clear all
set more off 
set maxvar 30000


use "randhrs1992_2020v1.dta",clear

merge 1:1 hhidpn using "$working\ssb70.dta",nogen keep (1 3)
merge 1:1 hhidpn using "$working\ssb65.dta",nogen keep (1 3)
merge 1:1 hhidpn using "$working\ssb62.dta",nogen keep (1 3)
merge 1:1 hhidpn using "$working\ssbfr.dta",nogen keep (1 3)
merge 1:1 hhidpn using "$working\ssb_retro.dta",nogen keep (1 3)
merge 1:1 hhidpn using "$working\industry.dta",nogen keep (1 3)



gen FRAm=0
replace FRAm = (65 * 12) if rabyear <= 1937
replace FRAm = (65 * 12) + 2 if rabyear == 1938
replace FRAm = (65 * 12) + 4 if rabyear == 1939
replace FRAm = (65 * 12) + 6 if rabyear == 1940
replace FRAm = (65 * 12) + 8 if rabyear == 1941
replace FRAm = (65 * 12) + 10 if rabyear == 1942
replace FRAm = (66 * 12) if inrange(rabyear, 1943, 1954)
qui: replace FRAm = (66 * 12) + 2 if rabyear ==1955
qui: replace FRAm = (66 * 12) + 4 if rabyear ==1956
qui: replace FRAm = (66 * 12) + 6 if rabyear ==1957
qui: replace FRAm = (66 * 12) + 8 if rabyear ==1958
qui: replace FRAm = (66 * 12) + 10 if rabyear ==1959
qui: replace FRAm = (67 * 12) if rabyear >=1960
tab FRAm, m

* Years
gen FR=FRAm/12



*****Using CPI, adjust everything into 2020 dollars


*CPI 1951-2065
matrix CPI=(26.10, 26.70, 26.90, 27.00, 26.90, 27.30, 28.30, 29.10, 29.30, 29.80, 30.10, 30.40, 30.80, 31.20, 31.70, 32.60, 33.60, 35.00, 36.90, 39.00, 40.70, 42.10, 44.70, 49.60, 54.10, 57.20, 60.90, 65.60, 73.10, 82.90, 91.40, 96.90, 99.80, 103.30, 106.90, 108.60, 112.50, 117.00, 122.60, 129.00, 134.30, 138.20, 142.10, 145.60, 149.80, 154.10, 157.60, 159.70, 163.20, 168.90, 173.50, 175.90, 179.80, 184.50, 191.00, 197.10, 202.77, 211.05, 209.63, 213.97, 221.58, 226.23, 229.32, 232.77, 231.81, 234.08, 239.05, 245.15, 249.22, 252.25, 265.51, 287.98, 294.90, 301.97, 309.22, 316.64, 324.24, 332.02, 339.99, 348.15, 356.51, 365.06, 373.82, 382.80, 391.98, 401.39, 411.02, 420.89, 430.99, 441.33, 451.93, 462.77, 473.88, 485.25, 496.90, 508.82, 521.04, 533.54, 546.35, 559.46, 572.88, 586.63, 600.71, 615.13, 629.89, 645.01, 660.49, 676.34, 692.57, 709.20, 726.22, 743.65, 761.49, 779.77, 798.48)



foreach val in 62 65 FR 70{
	gen cpi_`val'=CPI[1,round(rabyear+`val')-1950] 
}



replace SSB62=SSB62*CPI[1,2020-1950]/cpi_62
replace SSB65=SSB65*CPI[1,2020-1950]/cpi_65
replace SSBFR=SSBFR*CPI[1,2020-1950]/cpi_FR
replace SSB70=SSB70*CPI[1,2020-1950]/cpi_70
replace SSB62_ret=SSB62_ret*CPI[1,2020-1950]/cpi_62
replace SSB65_ret=SSB65_ret*CPI[1,2020-1950]/cpi_65
replace SSBFR_ret=SSBFR_ret*CPI[1,2020-1950]/cpi_FR
replace SSB70_ret=SSB70_ret*CPI[1,2020-1950]/cpi_70




*-------------------------------------------------------------------------------------------------------*
*step 1 - find SSB wealth ratios to update retro amounts (for future: find one ratio for each FRA group)
*-------------------------------------------------------------------------------------------------------*

bys FRAm: egen ratio6265=mean(SSB62/SSB65)
bys FRAm: egen ratio6270=mean(SSB62/SSB70)
bys FRAm: egen ratio62FR=mean(SSB62/SSBFR)
bys FRAm: egen ratio6570=mean(SSB65/SSB70)
bys FRAm: egen ratio65FR=mean(SSB65/SSBFR)
bys FRAm: egen ratioFR70=mean(SSBFR/SSB70)

gen group=.
replace group=1 if inrange(claimage,61,63.99)
replace group=2 if inrange(claimage,64,65.99)
replace group=3 if inrange(claimage,66,67.99)
replace group=4 if inrange(claimage,68,70)

*group1
replace SSB65_ret=SSB62_ret*1/ratio6265 if group==1
replace SSBFR_ret=SSB62_ret*1/ratio62FR if group==1
replace SSB70_ret=SSB62_ret*1/ratio6270 if group==1

*group2
replace SSB62_ret=SSB65_ret*ratio6265 if group==2
replace SSBFR_ret=SSB65_ret*1/ratio65FR if group==2
replace SSB70_ret=SSB65_ret*1/ratio6570 if group==2

*group3
replace SSB62_ret=SSBFR_ret*ratio62FR if group==3
replace SSB65_ret=SSBFR_ret*ratio65FR if group==3
replace SSB70_ret=SSBFR_ret*1/ratioFR70 if group==3

*group4
replace SSB62_ret=SSB70_ret*ratio6270 if group==4
replace SSB65_ret=SSB70_ret*ratio6570 if group==4
replace SSBFR_ret=SSB70_ret*ratioFR70 if group==4

*-------------------------------------------------------------------------------------------------------*


*flags
gen imp_flag=3
replace imp_flag=1 if SSB62!=.
replace imp_flag=2 if SSB62==. & SSB62_ret!=.
replace imp_flag=4 if rabyear<1917
label define imp_flag 1 "earnings file" 2 "retrospective" 3 "imputed" 4 "born before 1917"
label values imp_flag imp_flag

tab imp_flag if rabyear>=1917

gen SSB_62=SSB62
replace SSB_62=SSB62_ret if SSB62==.

gen SSB_65=SSB65
replace SSB_65=SSB65_ret if SSB65==.

gen SSB_FR=SSBFR
replace SSB_FR=SSBFR_ret if SSBFR==.

gen SSB_70=SSB70
replace SSB_70=SSB70_ret if SSB70==.



*if never worked by first interview and has no earnings record, make benefits zero and flag 2
gen neverworked=.
forvalues i=1/15{
	replace neverworked=0 if r`i'iwendy!=. & neverworked==.
	replace neverworked=1 if r`i'jlasty==.n 
}

replace SSB_62=0 if neverworked==1 & imp_flag==3
replace SSB_65=0 if neverworked==1 & imp_flag==3
replace SSB_FR=0 if neverworked==1 & imp_flag==3
replace SSB_70=0 if neverworked==1 & imp_flag==3

replace imp_flag=2 if neverworked==1 & imp_flag==3



*-----------------------------------------------*
* IMPUTATION --- nearest neighbor
*-----------------------------------------------*

gen college=(inlist(raeduc,4,5))
gen nonwhite=(rarace!=1)


mi set wide
mi register imputed SSB_62 SSB_65 SSB_FR SSB_70
mi impute monotone (pmm, knn(1)) SSB_62 SSB_65 SSB_FR SSB_70 = ragender i.hacoh rabyear i.nonwhite i.college i.indust, replace add(1) force

*if industry is missing
mi impute monotone (pmm, knn(1)) SSB_62 SSB_65 SSB_FR SSB_70 = ragender i.hacoh rabyear i.nonwhite i.college, add(1) force

/*
mi impute pmm SSB_62  ragender i.hacoh rabyear i.nonwhite i.college i.indust, replace add(1) knn(1) force
mi impute pmm SSB_FR  SSB_62 SSB_65 ragender i.hacoh rabyear i.nonwhite i.college i.indust, replace knn(1) force
mi impute pmm SSB_70  SSB_62 SSB_65 ragender i.hacoh rabyear i.nonwhite i.college i.indust, replace knn(1) force
*/
*replace with these imputed values
foreach val in 62 65 70 FR{
	replace SSB_`val'=_1_SSB_`val' if _mi_miss==1
	replace SSB_`val'=_2_SSB_`val' if _mi_miss==1 & _1_SSB_`val'==.
}

mi unset
drop SSB_62_* SSB_65_*  SSB_70_* SSB_FR_* mi_miss


*readjust back to nominal dollars
replace SSB_62=SSB_62*cpi_62/CPI[1,2020-1950]
replace SSB_65=SSB_65*cpi_65/CPI[1,2020-1950]
replace SSB_FR=SSB_FR*cpi_FR/CPI[1,2020-1950]
replace SSB_70=SSB_70*cpi_70/CPI[1,2020-1950]

preserve
keep hhidpn SSB_* imp_flag ragender hacoh nonwhite college indust rabyear FR
save "$working\SSB for RR.dta",replace
restore

*-----------------------------------------------*
* Match benefits of all spouses 
*-----------------------------------------------*

*record the id (1-4) for each wave
*record their birthyear
*record if they were married for 10 years or more at the time of each interview

for num 1/4: gen byearX=.
for num 1/4: gen sgenderX=.

forvalues i=1/15{
	gen w`i'_sn=.
	replace w`i'_sn=1 if raspid1==s`i'hhidpn & !missing(raspid1)
	replace w`i'_sn=2 if raspid2==s`i'hhidpn & !missing(raspid2)
	replace w`i'_sn=3 if raspid3==s`i'hhidpn & !missing(raspid3)
	replace w`i'_sn=4 if raspid4==s`i'hhidpn & !missing(raspid4)
	
	replace byear1=s`i'byear if w`i'_sn==1
	replace byear2=s`i'byear if w`i'_sn==2
	replace byear3=s`i'byear if w`i'_sn==3
	replace byear4=s`i'byear if w`i'_sn==4
	
	gen mar_m10_`i'=(!missing(r`i'mcurln) & r`i'mcurln>=10)
	
	replace sgender1=s`i'gender if w`i'_sn==1
	replace sgender2=s`i'gender if w`i'_sn==2
	replace sgender3=s`i'gender if w`i'_sn==3
	replace sgender4=s`i'gender if w`i'_sn==4
	
}



*-------------------------------------------------------------------------------*
* Find annual benefits from 62 to 119 using COLA adjustments
*-------------------------------------------------------------------------------*

* Starts at 1975 -2120
matrix COLA = (8.0,6.4,5.9,6.5,9.9,14.3,11.2,7.4,3.5,3.5,3.1,1.3,4.2,4.0,4.7,5.4,3.7,3.0,2.6,2.8,2.6,2.9,2.1,1.3,2.5,3.5,2.6,1.4,2.1,2.7,4.1,3.3,2.3,5.8,0.0,0.0,3.6,1.7,1.5,1.7,0.0,0.3,2.0,2.8,1.6,1.3,5.9,8.7,3.3,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4,2.4) 

*turn cola into index
matrix def COLA_ind=J(1,146,.)
matrix COLA_ind[1,1]=100
forvalues i=2/146{
	local j=`i'-1
	matrix COLA_ind[1,`i']=COLA_ind[1,`j']*(1+COLA[1,`i']/100)
}

for num 62/119: gen year_X=rabyear+X
gen year_FR=round(rabyear+FR)

forvalues a=62/119{
 gen cola`a'=COLA_ind[1,year_`a'-1974]
}
gen colaFR=COLA_ind[1,year_FR-1974]



*merge all spouse benefits and their baseline cola indexes
preserve
keep hhidpn SSB_62 SSB_65 SSB_FR SSB_70 cola62 cola65 colaFR cola70
forvalues i=1/4{
rename hhidpn raspid`i'
rename SSB_* _`i'_SSB* 
rename cola* _`i'_cola*
save "$working\forsp`i'.dta",replace
rename  raspid`i' hhidpn
rename _`i'_SSB*  SSB_*
rename  _`i'_cola* cola*
}
restore

forvalues i=1/4{
merge m:1 raspid`i' using  "$working\forsp`i'.dta",gen(m`i') keep(1 3)
gen sp`i'_nr=(m`i'==1 & raspid`i'!=.)
drop if hhidpn==.
}

*there are 1020 non-respondent spouses (for first spouse) -impute for these people - based mainly on respondent's characteristics
*before saving only keep necessary variables
keep hhidpn raspid* ragender sgender* r*agey_m r*iwendy SSB_* cola* byear* rabyear year_* _1_cola* _2_cola* _3_cola* _4_cola* w*_sn  mar_m10* cpi_62 cpi_70 cpi_65 cpi_FR imp_flag _1_SSB* _2_SSB* _3_SSB* _4_SSB* FRA sp*_nr claimage
save "$working\merged.dta",replace

