********************************************************************************
*cumulative mortality rates at each wave and each age for respondent and spouse
********************************************************************************

clear all
set more off 
set maxvar 30000



use "$working\merged.dta",clear

*benefit of spouse when respondent is 62 -119
for num 62/119: gen auxX=X

keep hhidpn aux* rabyear ragender byear* sgender* r*agey_m w*_sn
reshape long aux, i(hhidpn) j(age)

*for the oldest use 1900 levels
gen actual_rabyear=rabyear
gen actual_ragender=ragender
gen actual_age=age
replace rabyear=1900 if rabyear<1900
*1 person has missing birth year

*own mortality
merge m:1 rabyear ragender age using "$working\mort.dta"
drop if _m==2
drop _m

rename clx r_clx



*spouse mortality
gen year=actual_rabyear+age
for num 1/4: gen sageX=year-byearX


forvalues i=1/4{
cap drop ragender rabyear age

gen ragender=sgender`i'
gen rabyear=byear`i'
replace rabyear=1900 if byear`i'<1900
gen age=sage`i'
merge m:1 rabyear ragender age using "$working\mort.dta", keep(1 3) nogen
rename clx s`i'_clx

}

drop ragender rabyear age

*make survival prob 0 for older ages
for num 1/4: replace sX_clx=0 if sageX>119 & !missing(sageX)


*cumu. probability of surviving to each wave
forvalues w=1/15{
	local y=`w'*2+1990
	gen age`w'=r`w'agey_m
	replace age`w'=`y'-actual_rabyear if missing(r`w'agey_m)
	
	gen s1_age`w'=`y'-byear1
	gen s2_age`w'=`y'-byear2
	gen s3_age`w'=`y'-byear3
	gen s4_age`w'=`y'-byear4

}



gen ragender=actual_ragender
gen rabyear=actual_rabyear
replace rabyear=1900 if rabyear<1900

forvalues i=1/15{
gen age=age`i'
merge m:1 rabyear ragender age using "$working\mort.dta", keep(1 3) nogen
rename clx r_clx_w`i'
drop age	
}
drop ragender rabyear


*find which wife
*record their age
forvalues i=1/15{
 gen s`i'age=s1_age`i'	if w`i'_sn==1
 replace s`i'age=s2_age`i'	if w`i'_sn==2
 replace s`i'age=s3_age`i'	if w`i'_sn==3
 replace s`i'age=s4_age`i'	if w`i'_sn==4
 
 gen s`i'byear=byear1 if w`i'_sn==1
 replace s`i'byear=byear2 if w`i'_sn==2
 replace s`i'byear=byear3 if w`i'_sn==3
 replace s`i'byear=byear4 if w`i'_sn==4
 
 gen s`i'gender=sgender1 if w`i'_sn==1
 replace s`i'gender=sgender2 if w`i'_sn==2
 replace s`i'gender=sgender3 if w`i'_sn==3
 replace s`i'gender=sgender4 if w`i'_sn==4
 
 
}

drop s*_age*  




forvalues i=1/15{
	
gen ragender=s`i'gender
gen rabyear=s`i'byear
replace rabyear=1900 if rabyear<1900	
gen age=s`i'age
merge m:1 rabyear ragender age using "$working\mort.dta", keep(1 3) nogen
rename clx s_clx_w`i'
drop age ragender rabyear	
}

keep hhidpn actual_age r_clx* s1_clx* s2_clx* s3_clx* s4_clx* s_clx*
save "$working\cp_tomerge.dta",replace