clear all
set more off 
set maxvar 30000


use "randhrs1992_2020v1.dta",clear

merge 1:1 hhidpn using "$working\merged.dta"
drop cola* year* _1_cola* _2_cola* _3_cola* _4_cola* _1_SSB* _2_SSB* _3_SSB* _4_SSB*

merge 1:1 hhidpn using "$working\SSW62.dta",nogen keep(1 3)
merge 1:1 hhidpn using "$working\SSW65.dta",nogen keep(1 3)
merge 1:1 hhidpn using "$working\SSWFR.dta",nogen keep(1 3)
merge 1:1 hhidpn using "$working\SSW70.dta",nogen keep(1 3)

*find household wealth by wave
forvalues i=1/15{
	bys h`i'hhid: egen hep62_`i'=sum(epv62_`i')
	bys h`i'hhid: egen hep65_`i'=sum(epv65_`i')
	bys h`i'hhid: egen hepFR_`i'=sum(epvFR_`i')
	bys h`i'hhid: egen hep70_`i'=sum(epv70_`i')
}

*non-respondent in each wave
forvalues i=1/15{
gen sp_nr_`i'=1 if (sp1_nr==1	& w`i'_sn==1) | (sp2_nr==1	& w`i'_sn==2) | (sp3_nr==1	& w`i'_sn==3) | (sp4_nr==1	& w`i'_sn==4)
replace hep62_`i'=. if (sp_nr_`i'==1 & mar_m10_`i'==1) | h`i'hhid==.
replace hep65_`i'=. if (sp_nr_`i'==1 & mar_m10_`i'==1) | h`i'hhid==.
replace hepFR_`i'=. if (sp_nr_`i'==1 & mar_m10_`i'==1) | h`i'hhid==.
replace hep70_`i'=. if (sp_nr_`i'==1 & mar_m10_`i'==1) | h`i'hhid==.

}

gen college=(inlist(raeduc,4,5))
gen nonwhite=(rarace!=1)

*there are a few non-respondent spouses with missing rabyear
*for them, make birthyear equal to respondent's for imputation purposes

forvalues i=1/15{
replace s`i'byear=rabyear if s`i'byear==.v	
gen married`i'=0
replace married`i'= 1 if (s`i'hhidpn!=. & s`i'hhidpn!=0)
egen s`i'totalinc=rowtotal(s`i'iearn s`i'ipena s`i'isret s`i'issdi s`i'iunwc s`i'igxfr s`i'unemp s`i'iwcmp),m
}


mi set wide
mi register imputed hep62_1 hep65_1 hep70_1 hepFR_1
mi impute monotone (pmm, knn(1)) hep62_1 hep65_1 hep70_1 hepFR_1 = ragender i.hacoh rabyear  i.nonwhite i.college  married1#c.s1byear r_epv62_1 s1total, replace add(1) force

foreach val in 62 65 70 FR{
	replace hep`val'_1=_1_hep`val'_1 if _mi_miss==1 & (sp_nr_1==1 & mar_m10_1==1)
	
}

mi unregister  hep62_1 hep65_1 hep70_1 hepFR_1

forvalues i=2/15{
mi register imputed hep62_`i' hep65_`i' hep70_`i' hepFR_`i'
mi impute monotone (pmm, knn(1)) hep62_`i' hep65_`i' hep70_`i' hepFR_`i' = ragender i.hacoh rabyear  i.nonwhite i.college  married`i'#c.s`i'byear r_epv62_`i' s`i'total, replace add(1) force

foreach val in 62 65 70 FR{
	*replace hep`val'_`i'=_`i'_hep`val'_`i' if _mi_miss==1 & (sp_nr_`i'==1 & mar_m10_`i'==1)
	replace hep`val'_`i'=_1_hep`val'_`i' if _mi_miss==1 & (sp_nr_`i'==1 & mar_m10_`i'==1)
	
}

mi unregister  hep62_`i' hep65_`i' hep70_`i' hepFR_`i'
}


mi unset


forvalues i=1/15{
	replace hep62_`i'=. if r`i'iwendy==.
	replace hep65_`i'=. if r`i'iwendy==.
	replace hepFR_`i'=. if r`i'iwendy==.
	replace hep70_`i'=. if r`i'iwendy==.
	
	replace epv62_`i'=. if r`i'iwendy==.
	replace epv65_`i'=. if r`i'iwendy==.
	replace epvFR_`i'=. if r`i'iwendy==.
	replace epv70_`i'=. if r`i'iwendy==.
	
	gen nonrsp_`i'=(sp_nr_`i'==1 & mar_m10_`i'==1)
	replace nonrsp_`i'=.  if r`i'iwendy==.
}


*br hepFR_1 hep70_1 hep65_1 hep62_1

keep hhidpn hep* epv* claimage imp_flag nonrsp_*
save "$working\hh_ssw.dta",replace